# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetricDataPoint(object):
    """
    The metric values with dimension details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetricDataPoint object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param value:
            The value to assign to the value property of this MetricDataPoint.
        :type value: float

        :param unit:
            The value to assign to the unit property of this MetricDataPoint.
        :type unit: str

        :param dimensions:
            The value to assign to the dimensions property of this MetricDataPoint.
        :type dimensions: list[oci.database_management.models.MetricDimensionDefinition]

        """
        self.swagger_types = {
            'value': 'float',
            'unit': 'str',
            'dimensions': 'list[MetricDimensionDefinition]'
        }

        self.attribute_map = {
            'value': 'value',
            'unit': 'unit',
            'dimensions': 'dimensions'
        }

        self._value = None
        self._unit = None
        self._dimensions = None

    @property
    def value(self):
        """
        Gets the value of this MetricDataPoint.
        The value of the metric.


        :return: The value of this MetricDataPoint.
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this MetricDataPoint.
        The value of the metric.


        :param value: The value of this MetricDataPoint.
        :type: float
        """
        self._value = value

    @property
    def unit(self):
        """
        Gets the unit of this MetricDataPoint.
        The unit of the metric value.


        :return: The unit of this MetricDataPoint.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this MetricDataPoint.
        The unit of the metric value.


        :param unit: The unit of this MetricDataPoint.
        :type: str
        """
        self._unit = unit

    @property
    def dimensions(self):
        """
        Gets the dimensions of this MetricDataPoint.
        The dimensions of the metric.


        :return: The dimensions of this MetricDataPoint.
        :rtype: list[oci.database_management.models.MetricDimensionDefinition]
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this MetricDataPoint.
        The dimensions of the metric.


        :param dimensions: The dimensions of this MetricDataPoint.
        :type: list[oci.database_management.models.MetricDimensionDefinition]
        """
        self._dimensions = dimensions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateBdsInstanceDetails(object):
    """
    The information about the new cluster.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateBdsInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateBdsInstanceDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateBdsInstanceDetails.
        :type display_name: str

        :param cluster_version:
            The value to assign to the cluster_version property of this CreateBdsInstanceDetails.
        :type cluster_version: str

        :param cluster_public_key:
            The value to assign to the cluster_public_key property of this CreateBdsInstanceDetails.
        :type cluster_public_key: str

        :param cluster_admin_password:
            The value to assign to the cluster_admin_password property of this CreateBdsInstanceDetails.
        :type cluster_admin_password: str

        :param is_high_availability:
            The value to assign to the is_high_availability property of this CreateBdsInstanceDetails.
        :type is_high_availability: bool

        :param is_secure:
            The value to assign to the is_secure property of this CreateBdsInstanceDetails.
        :type is_secure: bool

        :param network_config:
            The value to assign to the network_config property of this CreateBdsInstanceDetails.
        :type network_config: oci.bds.models.NetworkConfig

        :param bootstrap_script_url:
            The value to assign to the bootstrap_script_url property of this CreateBdsInstanceDetails.
        :type bootstrap_script_url: str

        :param nodes:
            The value to assign to the nodes property of this CreateBdsInstanceDetails.
        :type nodes: list[oci.bds.models.CreateNodeDetails]

        :param kerberos_realm_name:
            The value to assign to the kerberos_realm_name property of this CreateBdsInstanceDetails.
        :type kerberos_realm_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateBdsInstanceDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateBdsInstanceDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'cluster_version': 'str',
            'cluster_public_key': 'str',
            'cluster_admin_password': 'str',
            'is_high_availability': 'bool',
            'is_secure': 'bool',
            'network_config': 'NetworkConfig',
            'bootstrap_script_url': 'str',
            'nodes': 'list[CreateNodeDetails]',
            'kerberos_realm_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'cluster_version': 'clusterVersion',
            'cluster_public_key': 'clusterPublicKey',
            'cluster_admin_password': 'clusterAdminPassword',
            'is_high_availability': 'isHighAvailability',
            'is_secure': 'isSecure',
            'network_config': 'networkConfig',
            'bootstrap_script_url': 'bootstrapScriptUrl',
            'nodes': 'nodes',
            'kerberos_realm_name': 'kerberosRealmName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._cluster_version = None
        self._cluster_public_key = None
        self._cluster_admin_password = None
        self._is_high_availability = None
        self._is_secure = None
        self._network_config = None
        self._bootstrap_script_url = None
        self._nodes = None
        self._kerberos_realm_name = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateBdsInstanceDetails.
        The OCID of the compartment.


        :return: The compartment_id of this CreateBdsInstanceDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateBdsInstanceDetails.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this CreateBdsInstanceDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateBdsInstanceDetails.
        Name of the Big Data Service cluster.


        :return: The display_name of this CreateBdsInstanceDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateBdsInstanceDetails.
        Name of the Big Data Service cluster.


        :param display_name: The display_name of this CreateBdsInstanceDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def cluster_version(self):
        """
        **[Required]** Gets the cluster_version of this CreateBdsInstanceDetails.
        Version of the Hadoop distribution.


        :return: The cluster_version of this CreateBdsInstanceDetails.
        :rtype: str
        """
        return self._cluster_version

    @cluster_version.setter
    def cluster_version(self, cluster_version):
        """
        Sets the cluster_version of this CreateBdsInstanceDetails.
        Version of the Hadoop distribution.


        :param cluster_version: The cluster_version of this CreateBdsInstanceDetails.
        :type: str
        """
        self._cluster_version = cluster_version

    @property
    def cluster_public_key(self):
        """
        **[Required]** Gets the cluster_public_key of this CreateBdsInstanceDetails.
        The SSH public key used to authenticate the cluster connection.


        :return: The cluster_public_key of this CreateBdsInstanceDetails.
        :rtype: str
        """
        return self._cluster_public_key

    @cluster_public_key.setter
    def cluster_public_key(self, cluster_public_key):
        """
        Sets the cluster_public_key of this CreateBdsInstanceDetails.
        The SSH public key used to authenticate the cluster connection.


        :param cluster_public_key: The cluster_public_key of this CreateBdsInstanceDetails.
        :type: str
        """
        self._cluster_public_key = cluster_public_key

    @property
    def cluster_admin_password(self):
        """
        **[Required]** Gets the cluster_admin_password of this CreateBdsInstanceDetails.
        Base-64 encoded password for the cluster (and Cloudera Manager) admin user.


        :return: The cluster_admin_password of this CreateBdsInstanceDetails.
        :rtype: str
        """
        return self._cluster_admin_password

    @cluster_admin_password.setter
    def cluster_admin_password(self, cluster_admin_password):
        """
        Sets the cluster_admin_password of this CreateBdsInstanceDetails.
        Base-64 encoded password for the cluster (and Cloudera Manager) admin user.


        :param cluster_admin_password: The cluster_admin_password of this CreateBdsInstanceDetails.
        :type: str
        """
        self._cluster_admin_password = cluster_admin_password

    @property
    def is_high_availability(self):
        """
        **[Required]** Gets the is_high_availability of this CreateBdsInstanceDetails.
        Boolean flag specifying whether or not the cluster is highly available (HA).


        :return: The is_high_availability of this CreateBdsInstanceDetails.
        :rtype: bool
        """
        return self._is_high_availability

    @is_high_availability.setter
    def is_high_availability(self, is_high_availability):
        """
        Sets the is_high_availability of this CreateBdsInstanceDetails.
        Boolean flag specifying whether or not the cluster is highly available (HA).


        :param is_high_availability: The is_high_availability of this CreateBdsInstanceDetails.
        :type: bool
        """
        self._is_high_availability = is_high_availability

    @property
    def is_secure(self):
        """
        **[Required]** Gets the is_secure of this CreateBdsInstanceDetails.
        Boolean flag specifying whether or not the cluster should be set up as secure.


        :return: The is_secure of this CreateBdsInstanceDetails.
        :rtype: bool
        """
        return self._is_secure

    @is_secure.setter
    def is_secure(self, is_secure):
        """
        Sets the is_secure of this CreateBdsInstanceDetails.
        Boolean flag specifying whether or not the cluster should be set up as secure.


        :param is_secure: The is_secure of this CreateBdsInstanceDetails.
        :type: bool
        """
        self._is_secure = is_secure

    @property
    def network_config(self):
        """
        Gets the network_config of this CreateBdsInstanceDetails.

        :return: The network_config of this CreateBdsInstanceDetails.
        :rtype: oci.bds.models.NetworkConfig
        """
        return self._network_config

    @network_config.setter
    def network_config(self, network_config):
        """
        Sets the network_config of this CreateBdsInstanceDetails.

        :param network_config: The network_config of this CreateBdsInstanceDetails.
        :type: oci.bds.models.NetworkConfig
        """
        self._network_config = network_config

    @property
    def bootstrap_script_url(self):
        """
        Gets the bootstrap_script_url of this CreateBdsInstanceDetails.
        Pre-authenticated URL of the script in Object Store that is downloaded and executed.


        :return: The bootstrap_script_url of this CreateBdsInstanceDetails.
        :rtype: str
        """
        return self._bootstrap_script_url

    @bootstrap_script_url.setter
    def bootstrap_script_url(self, bootstrap_script_url):
        """
        Sets the bootstrap_script_url of this CreateBdsInstanceDetails.
        Pre-authenticated URL of the script in Object Store that is downloaded and executed.


        :param bootstrap_script_url: The bootstrap_script_url of this CreateBdsInstanceDetails.
        :type: str
        """
        self._bootstrap_script_url = bootstrap_script_url

    @property
    def nodes(self):
        """
        **[Required]** Gets the nodes of this CreateBdsInstanceDetails.
        The list of nodes in the Big Data Service cluster.


        :return: The nodes of this CreateBdsInstanceDetails.
        :rtype: list[oci.bds.models.CreateNodeDetails]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """
        Sets the nodes of this CreateBdsInstanceDetails.
        The list of nodes in the Big Data Service cluster.


        :param nodes: The nodes of this CreateBdsInstanceDetails.
        :type: list[oci.bds.models.CreateNodeDetails]
        """
        self._nodes = nodes

    @property
    def kerberos_realm_name(self):
        """
        Gets the kerberos_realm_name of this CreateBdsInstanceDetails.
        The user-defined kerberos realm name.


        :return: The kerberos_realm_name of this CreateBdsInstanceDetails.
        :rtype: str
        """
        return self._kerberos_realm_name

    @kerberos_realm_name.setter
    def kerberos_realm_name(self, kerberos_realm_name):
        """
        Sets the kerberos_realm_name of this CreateBdsInstanceDetails.
        The user-defined kerberos realm name.


        :param kerberos_realm_name: The kerberos_realm_name of this CreateBdsInstanceDetails.
        :type: str
        """
        self._kerberos_realm_name = kerberos_realm_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateBdsInstanceDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Exists for cross-compatibility only. For example, `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateBdsInstanceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateBdsInstanceDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Exists for cross-compatibility only. For example, `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateBdsInstanceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateBdsInstanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example, `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateBdsInstanceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateBdsInstanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example, `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateBdsInstanceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .activate_target_database_details import ActivateTargetDatabaseDetails
from .alert import Alert
from .alert_aggregation_items import AlertAggregationItems
from .alert_analytics_collection import AlertAnalyticsCollection
from .alert_collection import AlertCollection
from .alert_policy import AlertPolicy
from .alert_policy_collection import AlertPolicyCollection
from .alert_policy_rule import AlertPolicyRule
from .alert_policy_rule_collection import AlertPolicyRuleCollection
from .alert_policy_rule_summary import AlertPolicyRuleSummary
from .alert_policy_summary import AlertPolicySummary
from .alert_summary import AlertSummary
from .alerts_aggregation_dimension import AlertsAggregationDimension
from .apply_discovery_job_results_details import ApplyDiscoveryJobResultsDetails
from .audit_archive_retrieval import AuditArchiveRetrieval
from .audit_archive_retrieval_collection import AuditArchiveRetrievalCollection
from .audit_archive_retrieval_summary import AuditArchiveRetrievalSummary
from .audit_conditions import AuditConditions
from .audit_event_aggregation_dimensions import AuditEventAggregationDimensions
from .audit_event_aggregation_items import AuditEventAggregationItems
from .audit_event_analytics_collection import AuditEventAnalyticsCollection
from .audit_event_collection import AuditEventCollection
from .audit_event_summary import AuditEventSummary
from .audit_policy import AuditPolicy
from .audit_policy_aggregation_items import AuditPolicyAggregationItems
from .audit_policy_analytic_collection import AuditPolicyAnalyticCollection
from .audit_policy_collection import AuditPolicyCollection
from .audit_policy_dimensions import AuditPolicyDimensions
from .audit_policy_summary import AuditPolicySummary
from .audit_profile import AuditProfile
from .audit_profile_aggregation_items import AuditProfileAggregationItems
from .audit_profile_analytic_collection import AuditProfileAnalyticCollection
from .audit_profile_collection import AuditProfileCollection
from .audit_profile_dimensions import AuditProfileDimensions
from .audit_profile_summary import AuditProfileSummary
from .audit_specification import AuditSpecification
from .audit_trail import AuditTrail
from .audit_trail_aggregation_items import AuditTrailAggregationItems
from .audit_trail_analytic_collection import AuditTrailAnalyticCollection
from .audit_trail_collection import AuditTrailCollection
from .audit_trail_dimensions import AuditTrailDimensions
from .audit_trail_summary import AuditTrailSummary
from .autonomous_database_details import AutonomousDatabaseDetails
from .available_audit_volume_collection import AvailableAuditVolumeCollection
from .available_audit_volume_summary import AvailableAuditVolumeSummary
from .calculate_audit_volume_available_details import CalculateAuditVolumeAvailableDetails
from .calculate_audit_volume_collected_details import CalculateAuditVolumeCollectedDetails
from .change_alert_compartment_details import ChangeAlertCompartmentDetails
from .change_alert_policy_compartment_details import ChangeAlertPolicyCompartmentDetails
from .change_audit_archive_retrieval_compartment_details import ChangeAuditArchiveRetrievalCompartmentDetails
from .change_audit_policy_compartment_details import ChangeAuditPolicyCompartmentDetails
from .change_audit_profile_compartment_details import ChangeAuditProfileCompartmentDetails
from .change_data_safe_private_endpoint_compartment_details import ChangeDataSafePrivateEndpointCompartmentDetails
from .change_discovery_job_compartment_details import ChangeDiscoveryJobCompartmentDetails
from .change_library_masking_format_compartment_details import ChangeLibraryMaskingFormatCompartmentDetails
from .change_masking_policy_compartment_details import ChangeMaskingPolicyCompartmentDetails
from .change_on_prem_connector_compartment_details import ChangeOnPremConnectorCompartmentDetails
from .change_report_compartment_details import ChangeReportCompartmentDetails
from .change_report_definition_compartment_details import ChangeReportDefinitionCompartmentDetails
from .change_retention_details import ChangeRetentionDetails
from .change_security_assessment_compartment_details import ChangeSecurityAssessmentCompartmentDetails
from .change_sensitive_data_model_compartment_details import ChangeSensitiveDataModelCompartmentDetails
from .change_sensitive_type_compartment_details import ChangeSensitiveTypeCompartmentDetails
from .change_target_alert_policy_association_compartment_details import ChangeTargetAlertPolicyAssociationCompartmentDetails
from .change_target_database_compartment_details import ChangeTargetDatabaseCompartmentDetails
from .change_user_assessment_compartment_details import ChangeUserAssessmentCompartmentDetails
from .collected_audit_volume_collection import CollectedAuditVolumeCollection
from .collected_audit_volume_summary import CollectedAuditVolumeSummary
from .column import Column
from .column_filter import ColumnFilter
from .column_sorting import ColumnSorting
from .column_source_details import ColumnSourceDetails
from .column_source_from_sdm_details import ColumnSourceFromSdmDetails
from .column_source_from_target_details import ColumnSourceFromTargetDetails
from .column_summary import ColumnSummary
from .compare_security_assessment_details import CompareSecurityAssessmentDetails
from .compare_user_assessment_details import CompareUserAssessmentDetails
from .compatible_formats_for_data_types import CompatibleFormatsForDataTypes
from .compatible_formats_for_sensitive_types import CompatibleFormatsForSensitiveTypes
from .connection_option import ConnectionOption
from .create_alert_policy_details import CreateAlertPolicyDetails
from .create_alert_policy_rule_details import CreateAlertPolicyRuleDetails
from .create_audit_archive_retrieval_details import CreateAuditArchiveRetrievalDetails
from .create_audit_policy_details import CreateAuditPolicyDetails
from .create_audit_profile_details import CreateAuditProfileDetails
from .create_column_source_details import CreateColumnSourceDetails
from .create_column_source_from_sdm_details import CreateColumnSourceFromSdmDetails
from .create_column_source_from_target_details import CreateColumnSourceFromTargetDetails
from .create_data_safe_private_endpoint_details import CreateDataSafePrivateEndpointDetails
from .create_discovery_job_details import CreateDiscoveryJobDetails
from .create_library_masking_format_details import CreateLibraryMaskingFormatDetails
from .create_masking_column_details import CreateMaskingColumnDetails
from .create_masking_policy_details import CreateMaskingPolicyDetails
from .create_on_prem_connector_details import CreateOnPremConnectorDetails
from .create_report_definition_details import CreateReportDefinitionDetails
from .create_security_assessment_details import CreateSecurityAssessmentDetails
from .create_sensitive_category_details import CreateSensitiveCategoryDetails
from .create_sensitive_column_details import CreateSensitiveColumnDetails
from .create_sensitive_data_model_details import CreateSensitiveDataModelDetails
from .create_sensitive_type_details import CreateSensitiveTypeDetails
from .create_sensitive_type_pattern_details import CreateSensitiveTypePatternDetails
from .create_target_alert_policy_association_details import CreateTargetAlertPolicyAssociationDetails
from .create_target_database_details import CreateTargetDatabaseDetails
from .create_user_assessment_details import CreateUserAssessmentDetails
from .credentials import Credentials
from .data_safe_configuration import DataSafeConfiguration
from .data_safe_private_endpoint import DataSafePrivateEndpoint
from .data_safe_private_endpoint_summary import DataSafePrivateEndpointSummary
from .database_cloud_service_details import DatabaseCloudServiceDetails
from .database_details import DatabaseDetails
from .delete_rows_format_entry import DeleteRowsFormatEntry
from .deterministic_encryption_date_format_entry import DeterministicEncryptionDateFormatEntry
from .deterministic_encryption_format_entry import DeterministicEncryptionFormatEntry
from .deterministic_substitution_format_entry import DeterministicSubstitutionFormatEntry
from .diffs import Diffs
from .dimensions import Dimensions
from .discovery_analytics_collection import DiscoveryAnalyticsCollection
from .discovery_analytics_summary import DiscoveryAnalyticsSummary
from .discovery_job import DiscoveryJob
from .discovery_job_collection import DiscoveryJobCollection
from .discovery_job_result import DiscoveryJobResult
from .discovery_job_result_collection import DiscoveryJobResultCollection
from .discovery_job_result_summary import DiscoveryJobResultSummary
from .discovery_job_summary import DiscoveryJobSummary
from .download_discovery_report_details import DownloadDiscoveryReportDetails
from .download_masking_log_details import DownloadMaskingLogDetails
from .download_masking_policy_details import DownloadMaskingPolicyDetails
from .download_masking_report_details import DownloadMaskingReportDetails
from .download_security_assessment_report_details import DownloadSecurityAssessmentReportDetails
from .download_sensitive_data_model_details import DownloadSensitiveDataModelDetails
from .download_user_assessment_report_details import DownloadUserAssessmentReportDetails
from .enable_conditions import EnableConditions
from .enable_data_safe_configuration_details import EnableDataSafeConfigurationDetails
from .finding import Finding
from .finding_summary import FindingSummary
from .fixed_number_format_entry import FixedNumberFormatEntry
from .fixed_string_format_entry import FixedStringFormatEntry
from .format_entry import FormatEntry
from .format_summary import FormatSummary
from .formats_for_data_type import FormatsForDataType
from .formats_for_sensitive_type import FormatsForSensitiveType
from .generate_discovery_report_for_download_details import GenerateDiscoveryReportForDownloadDetails
from .generate_masking_policy_for_download_details import GenerateMaskingPolicyForDownloadDetails
from .generate_masking_report_for_download_details import GenerateMaskingReportForDownloadDetails
from .generate_on_prem_connector_configuration_details import GenerateOnPremConnectorConfigurationDetails
from .generate_report_details import GenerateReportDetails
from .generate_security_assessment_report_details import GenerateSecurityAssessmentReportDetails
from .generate_sensitive_data_model_for_download_details import GenerateSensitiveDataModelForDownloadDetails
from .generate_user_assessment_report_details import GenerateUserAssessmentReportDetails
from .global_settings import GlobalSettings
from .grant_summary import GrantSummary
from .initialization_parameter import InitializationParameter
from .installed_database_details import InstalledDatabaseDetails
from .library_masking_format import LibraryMaskingFormat
from .library_masking_format_collection import LibraryMaskingFormatCollection
from .library_masking_format_entry import LibraryMaskingFormatEntry
from .library_masking_format_summary import LibraryMaskingFormatSummary
from .mask_data_details import MaskDataDetails
from .masked_column_collection import MaskedColumnCollection
from .masked_column_summary import MaskedColumnSummary
from .masking_analytics_collection import MaskingAnalyticsCollection
from .masking_analytics_dimensions import MaskingAnalyticsDimensions
from .masking_analytics_summary import MaskingAnalyticsSummary
from .masking_column import MaskingColumn
from .masking_column_collection import MaskingColumnCollection
from .masking_column_summary import MaskingColumnSummary
from .masking_format import MaskingFormat
from .masking_policy import MaskingPolicy
from .masking_policy_collection import MaskingPolicyCollection
from .masking_policy_summary import MaskingPolicySummary
from .masking_report import MaskingReport
from .masking_report_collection import MaskingReportCollection
from .masking_report_summary import MaskingReportSummary
from .modified_attributes import ModifiedAttributes
from .modify_global_settings_details import ModifyGlobalSettingsDetails
from .null_value_format_entry import NullValueFormatEntry
from .on_prem_connector import OnPremConnector
from .on_prem_connector_summary import OnPremConnectorSummary
from .on_premise_connector import OnPremiseConnector
from .ppf_format_entry import PPFFormatEntry
from .patch_alert_policy_rule_details import PatchAlertPolicyRuleDetails
from .patch_alerts_details import PatchAlertsDetails
from .patch_discovery_job_result_details import PatchDiscoveryJobResultDetails
from .patch_insert_instruction import PatchInsertInstruction
from .patch_instruction import PatchInstruction
from .patch_masking_columns_details import PatchMaskingColumnsDetails
from .patch_merge_instruction import PatchMergeInstruction
from .patch_remove_instruction import PatchRemoveInstruction
from .patch_sensitive_column_details import PatchSensitiveColumnDetails
from .preserve_original_data_format_entry import PreserveOriginalDataFormatEntry
from .private_endpoint import PrivateEndpoint
from .profile_details import ProfileDetails
from .provision_audit_conditions import ProvisionAuditConditions
from .provision_audit_policy_details import ProvisionAuditPolicyDetails
from .random_date_format_entry import RandomDateFormatEntry
from .random_decimal_number_format_entry import RandomDecimalNumberFormatEntry
from .random_digits_format_entry import RandomDigitsFormatEntry
from .random_list_format_entry import RandomListFormatEntry
from .random_number_format_entry import RandomNumberFormatEntry
from .random_string_format_entry import RandomStringFormatEntry
from .random_substitution_format_entry import RandomSubstitutionFormatEntry
from .references import References
from .regular_expression_format_entry import RegularExpressionFormatEntry
from .report import Report
from .report_collection import ReportCollection
from .report_definition import ReportDefinition
from .report_definition_collection import ReportDefinitionCollection
from .report_definition_summary import ReportDefinitionSummary
from .report_summary import ReportSummary
from .role_summary import RoleSummary
from .run_security_assessment_details import RunSecurityAssessmentDetails
from .run_user_assessment_details import RunUserAssessmentDetails
from .sql_expression_format_entry import SQLExpressionFormatEntry
from .schema_summary import SchemaSummary
from .section_statistics import SectionStatistics
from .security_assessment import SecurityAssessment
from .security_assessment_base_line_details import SecurityAssessmentBaseLineDetails
from .security_assessment_comparison import SecurityAssessmentComparison
from .security_assessment_comparison_per_target import SecurityAssessmentComparisonPerTarget
from .security_assessment_statistics import SecurityAssessmentStatistics
from .security_assessment_summary import SecurityAssessmentSummary
from .sensitive_category import SensitiveCategory
from .sensitive_column import SensitiveColumn
from .sensitive_column_collection import SensitiveColumnCollection
from .sensitive_column_summary import SensitiveColumnSummary
from .sensitive_data_model import SensitiveDataModel
from .sensitive_data_model_collection import SensitiveDataModelCollection
from .sensitive_data_model_summary import SensitiveDataModelSummary
from .sensitive_type import SensitiveType
from .sensitive_type_collection import SensitiveTypeCollection
from .sensitive_type_pattern import SensitiveTypePattern
from .sensitive_type_summary import SensitiveTypeSummary
from .shuffle_format_entry import ShuffleFormatEntry
from .start_audit_trail_details import StartAuditTrailDetails
from .substring_format_entry import SubstringFormatEntry
from .summary import Summary
from .table_summary import TableSummary
from .target_alert_policy_association import TargetAlertPolicyAssociation
from .target_alert_policy_association_collection import TargetAlertPolicyAssociationCollection
from .target_alert_policy_association_summary import TargetAlertPolicyAssociationSummary
from .target_database import TargetDatabase
from .target_database_summary import TargetDatabaseSummary
from .tls_config import TlsConfig
from .truncate_table_format_entry import TruncateTableFormatEntry
from .udf_format_entry import UDFFormatEntry
from .update_alert_details import UpdateAlertDetails
from .update_alert_policy_rule_details import UpdateAlertPolicyRuleDetails
from .update_audit_archive_retrieval_details import UpdateAuditArchiveRetrievalDetails
from .update_audit_policy_details import UpdateAuditPolicyDetails
from .update_audit_profile_details import UpdateAuditProfileDetails
from .update_audit_trail_details import UpdateAuditTrailDetails
from .update_column_source_details import UpdateColumnSourceDetails
from .update_column_source_sdm_details import UpdateColumnSourceSdmDetails
from .update_column_source_target_details import UpdateColumnSourceTargetDetails
from .update_data_safe_private_endpoint_details import UpdateDataSafePrivateEndpointDetails
from .update_library_masking_format_details import UpdateLibraryMaskingFormatDetails
from .update_masking_column_details import UpdateMaskingColumnDetails
from .update_masking_policy_details import UpdateMaskingPolicyDetails
from .update_on_prem_connector_details import UpdateOnPremConnectorDetails
from .update_on_prem_connector_wallet_details import UpdateOnPremConnectorWalletDetails
from .update_report_definition_details import UpdateReportDefinitionDetails
from .update_security_assessment_details import UpdateSecurityAssessmentDetails
from .update_sensitive_category_details import UpdateSensitiveCategoryDetails
from .update_sensitive_column_details import UpdateSensitiveColumnDetails
from .update_sensitive_data_model_details import UpdateSensitiveDataModelDetails
from .update_sensitive_type_details import UpdateSensitiveTypeDetails
from .update_sensitive_type_pattern_details import UpdateSensitiveTypePatternDetails
from .update_target_alert_policy_association_details import UpdateTargetAlertPolicyAssociationDetails
from .update_target_database_details import UpdateTargetDatabaseDetails
from .update_user_assessment_details import UpdateUserAssessmentDetails
from .user_aggregation import UserAggregation
from .user_assessment import UserAssessment
from .user_assessment_base_line_details import UserAssessmentBaseLineDetails
from .user_assessment_comparison import UserAssessmentComparison
from .user_assessment_summary import UserAssessmentSummary
from .user_details import UserDetails
from .user_summary import UserSummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for data_safe services.
data_safe_type_mapping = {
    "ActivateTargetDatabaseDetails": ActivateTargetDatabaseDetails,
    "Alert": Alert,
    "AlertAggregationItems": AlertAggregationItems,
    "AlertAnalyticsCollection": AlertAnalyticsCollection,
    "AlertCollection": AlertCollection,
    "AlertPolicy": AlertPolicy,
    "AlertPolicyCollection": AlertPolicyCollection,
    "AlertPolicyRule": AlertPolicyRule,
    "AlertPolicyRuleCollection": AlertPolicyRuleCollection,
    "AlertPolicyRuleSummary": AlertPolicyRuleSummary,
    "AlertPolicySummary": AlertPolicySummary,
    "AlertSummary": AlertSummary,
    "AlertsAggregationDimension": AlertsAggregationDimension,
    "ApplyDiscoveryJobResultsDetails": ApplyDiscoveryJobResultsDetails,
    "AuditArchiveRetrieval": AuditArchiveRetrieval,
    "AuditArchiveRetrievalCollection": AuditArchiveRetrievalCollection,
    "AuditArchiveRetrievalSummary": AuditArchiveRetrievalSummary,
    "AuditConditions": AuditConditions,
    "AuditEventAggregationDimensions": AuditEventAggregationDimensions,
    "AuditEventAggregationItems": AuditEventAggregationItems,
    "AuditEventAnalyticsCollection": AuditEventAnalyticsCollection,
    "AuditEventCollection": AuditEventCollection,
    "AuditEventSummary": AuditEventSummary,
    "AuditPolicy": AuditPolicy,
    "AuditPolicyAggregationItems": AuditPolicyAggregationItems,
    "AuditPolicyAnalyticCollection": AuditPolicyAnalyticCollection,
    "AuditPolicyCollection": AuditPolicyCollection,
    "AuditPolicyDimensions": AuditPolicyDimensions,
    "AuditPolicySummary": AuditPolicySummary,
    "AuditProfile": AuditProfile,
    "AuditProfileAggregationItems": AuditProfileAggregationItems,
    "AuditProfileAnalyticCollection": AuditProfileAnalyticCollection,
    "AuditProfileCollection": AuditProfileCollection,
    "AuditProfileDimensions": AuditProfileDimensions,
    "AuditProfileSummary": AuditProfileSummary,
    "AuditSpecification": AuditSpecification,
    "AuditTrail": AuditTrail,
    "AuditTrailAggregationItems": AuditTrailAggregationItems,
    "AuditTrailAnalyticCollection": AuditTrailAnalyticCollection,
    "AuditTrailCollection": AuditTrailCollection,
    "AuditTrailDimensions": AuditTrailDimensions,
    "AuditTrailSummary": AuditTrailSummary,
    "AutonomousDatabaseDetails": AutonomousDatabaseDetails,
    "AvailableAuditVolumeCollection": AvailableAuditVolumeCollection,
    "AvailableAuditVolumeSummary": AvailableAuditVolumeSummary,
    "CalculateAuditVolumeAvailableDetails": CalculateAuditVolumeAvailableDetails,
    "CalculateAuditVolumeCollectedDetails": CalculateAuditVolumeCollectedDetails,
    "ChangeAlertCompartmentDetails": ChangeAlertCompartmentDetails,
    "ChangeAlertPolicyCompartmentDetails": ChangeAlertPolicyCompartmentDetails,
    "ChangeAuditArchiveRetrievalCompartmentDetails": ChangeAuditArchiveRetrievalCompartmentDetails,
    "ChangeAuditPolicyCompartmentDetails": ChangeAuditPolicyCompartmentDetails,
    "ChangeAuditProfileCompartmentDetails": ChangeAuditProfileCompartmentDetails,
    "ChangeDataSafePrivateEndpointCompartmentDetails": ChangeDataSafePrivateEndpointCompartmentDetails,
    "ChangeDiscoveryJobCompartmentDetails": ChangeDiscoveryJobCompartmentDetails,
    "ChangeLibraryMaskingFormatCompartmentDetails": ChangeLibraryMaskingFormatCompartmentDetails,
    "ChangeMaskingPolicyCompartmentDetails": ChangeMaskingPolicyCompartmentDetails,
    "ChangeOnPremConnectorCompartmentDetails": ChangeOnPremConnectorCompartmentDetails,
    "ChangeReportCompartmentDetails": ChangeReportCompartmentDetails,
    "ChangeReportDefinitionCompartmentDetails": ChangeReportDefinitionCompartmentDetails,
    "ChangeRetentionDetails": ChangeRetentionDetails,
    "ChangeSecurityAssessmentCompartmentDetails": ChangeSecurityAssessmentCompartmentDetails,
    "ChangeSensitiveDataModelCompartmentDetails": ChangeSensitiveDataModelCompartmentDetails,
    "ChangeSensitiveTypeCompartmentDetails": ChangeSensitiveTypeCompartmentDetails,
    "ChangeTargetAlertPolicyAssociationCompartmentDetails": ChangeTargetAlertPolicyAssociationCompartmentDetails,
    "ChangeTargetDatabaseCompartmentDetails": ChangeTargetDatabaseCompartmentDetails,
    "ChangeUserAssessmentCompartmentDetails": ChangeUserAssessmentCompartmentDetails,
    "CollectedAuditVolumeCollection": CollectedAuditVolumeCollection,
    "CollectedAuditVolumeSummary": CollectedAuditVolumeSummary,
    "Column": Column,
    "ColumnFilter": ColumnFilter,
    "ColumnSorting": ColumnSorting,
    "ColumnSourceDetails": ColumnSourceDetails,
    "ColumnSourceFromSdmDetails": ColumnSourceFromSdmDetails,
    "ColumnSourceFromTargetDetails": ColumnSourceFromTargetDetails,
    "ColumnSummary": ColumnSummary,
    "CompareSecurityAssessmentDetails": CompareSecurityAssessmentDetails,
    "CompareUserAssessmentDetails": CompareUserAssessmentDetails,
    "CompatibleFormatsForDataTypes": CompatibleFormatsForDataTypes,
    "CompatibleFormatsForSensitiveTypes": CompatibleFormatsForSensitiveTypes,
    "ConnectionOption": ConnectionOption,
    "CreateAlertPolicyDetails": CreateAlertPolicyDetails,
    "CreateAlertPolicyRuleDetails": CreateAlertPolicyRuleDetails,
    "CreateAuditArchiveRetrievalDetails": CreateAuditArchiveRetrievalDetails,
    "CreateAuditPolicyDetails": CreateAuditPolicyDetails,
    "CreateAuditProfileDetails": CreateAuditProfileDetails,
    "CreateColumnSourceDetails": CreateColumnSourceDetails,
    "CreateColumnSourceFromSdmDetails": CreateColumnSourceFromSdmDetails,
    "CreateColumnSourceFromTargetDetails": CreateColumnSourceFromTargetDetails,
    "CreateDataSafePrivateEndpointDetails": CreateDataSafePrivateEndpointDetails,
    "CreateDiscoveryJobDetails": CreateDiscoveryJobDetails,
    "CreateLibraryMaskingFormatDetails": CreateLibraryMaskingFormatDetails,
    "CreateMaskingColumnDetails": CreateMaskingColumnDetails,
    "CreateMaskingPolicyDetails": CreateMaskingPolicyDetails,
    "CreateOnPremConnectorDetails": CreateOnPremConnectorDetails,
    "CreateReportDefinitionDetails": CreateReportDefinitionDetails,
    "CreateSecurityAssessmentDetails": CreateSecurityAssessmentDetails,
    "CreateSensitiveCategoryDetails": CreateSensitiveCategoryDetails,
    "CreateSensitiveColumnDetails": CreateSensitiveColumnDetails,
    "CreateSensitiveDataModelDetails": CreateSensitiveDataModelDetails,
    "CreateSensitiveTypeDetails": CreateSensitiveTypeDetails,
    "CreateSensitiveTypePatternDetails": CreateSensitiveTypePatternDetails,
    "CreateTargetAlertPolicyAssociationDetails": CreateTargetAlertPolicyAssociationDetails,
    "CreateTargetDatabaseDetails": CreateTargetDatabaseDetails,
    "CreateUserAssessmentDetails": CreateUserAssessmentDetails,
    "Credentials": Credentials,
    "DataSafeConfiguration": DataSafeConfiguration,
    "DataSafePrivateEndpoint": DataSafePrivateEndpoint,
    "DataSafePrivateEndpointSummary": DataSafePrivateEndpointSummary,
    "DatabaseCloudServiceDetails": DatabaseCloudServiceDetails,
    "DatabaseDetails": DatabaseDetails,
    "DeleteRowsFormatEntry": DeleteRowsFormatEntry,
    "DeterministicEncryptionDateFormatEntry": DeterministicEncryptionDateFormatEntry,
    "DeterministicEncryptionFormatEntry": DeterministicEncryptionFormatEntry,
    "DeterministicSubstitutionFormatEntry": DeterministicSubstitutionFormatEntry,
    "Diffs": Diffs,
    "Dimensions": Dimensions,
    "DiscoveryAnalyticsCollection": DiscoveryAnalyticsCollection,
    "DiscoveryAnalyticsSummary": DiscoveryAnalyticsSummary,
    "DiscoveryJob": DiscoveryJob,
    "DiscoveryJobCollection": DiscoveryJobCollection,
    "DiscoveryJobResult": DiscoveryJobResult,
    "DiscoveryJobResultCollection": DiscoveryJobResultCollection,
    "DiscoveryJobResultSummary": DiscoveryJobResultSummary,
    "DiscoveryJobSummary": DiscoveryJobSummary,
    "DownloadDiscoveryReportDetails": DownloadDiscoveryReportDetails,
    "DownloadMaskingLogDetails": DownloadMaskingLogDetails,
    "DownloadMaskingPolicyDetails": DownloadMaskingPolicyDetails,
    "DownloadMaskingReportDetails": DownloadMaskingReportDetails,
    "DownloadSecurityAssessmentReportDetails": DownloadSecurityAssessmentReportDetails,
    "DownloadSensitiveDataModelDetails": DownloadSensitiveDataModelDetails,
    "DownloadUserAssessmentReportDetails": DownloadUserAssessmentReportDetails,
    "EnableConditions": EnableConditions,
    "EnableDataSafeConfigurationDetails": EnableDataSafeConfigurationDetails,
    "Finding": Finding,
    "FindingSummary": FindingSummary,
    "FixedNumberFormatEntry": FixedNumberFormatEntry,
    "FixedStringFormatEntry": FixedStringFormatEntry,
    "FormatEntry": FormatEntry,
    "FormatSummary": FormatSummary,
    "FormatsForDataType": FormatsForDataType,
    "FormatsForSensitiveType": FormatsForSensitiveType,
    "GenerateDiscoveryReportForDownloadDetails": GenerateDiscoveryReportForDownloadDetails,
    "GenerateMaskingPolicyForDownloadDetails": GenerateMaskingPolicyForDownloadDetails,
    "GenerateMaskingReportForDownloadDetails": GenerateMaskingReportForDownloadDetails,
    "GenerateOnPremConnectorConfigurationDetails": GenerateOnPremConnectorConfigurationDetails,
    "GenerateReportDetails": GenerateReportDetails,
    "GenerateSecurityAssessmentReportDetails": GenerateSecurityAssessmentReportDetails,
    "GenerateSensitiveDataModelForDownloadDetails": GenerateSensitiveDataModelForDownloadDetails,
    "GenerateUserAssessmentReportDetails": GenerateUserAssessmentReportDetails,
    "GlobalSettings": GlobalSettings,
    "GrantSummary": GrantSummary,
    "InitializationParameter": InitializationParameter,
    "InstalledDatabaseDetails": InstalledDatabaseDetails,
    "LibraryMaskingFormat": LibraryMaskingFormat,
    "LibraryMaskingFormatCollection": LibraryMaskingFormatCollection,
    "LibraryMaskingFormatEntry": LibraryMaskingFormatEntry,
    "LibraryMaskingFormatSummary": LibraryMaskingFormatSummary,
    "MaskDataDetails": MaskDataDetails,
    "MaskedColumnCollection": MaskedColumnCollection,
    "MaskedColumnSummary": MaskedColumnSummary,
    "MaskingAnalyticsCollection": MaskingAnalyticsCollection,
    "MaskingAnalyticsDimensions": MaskingAnalyticsDimensions,
    "MaskingAnalyticsSummary": MaskingAnalyticsSummary,
    "MaskingColumn": MaskingColumn,
    "MaskingColumnCollection": MaskingColumnCollection,
    "MaskingColumnSummary": MaskingColumnSummary,
    "MaskingFormat": MaskingFormat,
    "MaskingPolicy": MaskingPolicy,
    "MaskingPolicyCollection": MaskingPolicyCollection,
    "MaskingPolicySummary": MaskingPolicySummary,
    "MaskingReport": MaskingReport,
    "MaskingReportCollection": MaskingReportCollection,
    "MaskingReportSummary": MaskingReportSummary,
    "ModifiedAttributes": ModifiedAttributes,
    "ModifyGlobalSettingsDetails": ModifyGlobalSettingsDetails,
    "NullValueFormatEntry": NullValueFormatEntry,
    "OnPremConnector": OnPremConnector,
    "OnPremConnectorSummary": OnPremConnectorSummary,
    "OnPremiseConnector": OnPremiseConnector,
    "PPFFormatEntry": PPFFormatEntry,
    "PatchAlertPolicyRuleDetails": PatchAlertPolicyRuleDetails,
    "PatchAlertsDetails": PatchAlertsDetails,
    "PatchDiscoveryJobResultDetails": PatchDiscoveryJobResultDetails,
    "PatchInsertInstruction": PatchInsertInstruction,
    "PatchInstruction": PatchInstruction,
    "PatchMaskingColumnsDetails": PatchMaskingColumnsDetails,
    "PatchMergeInstruction": PatchMergeInstruction,
    "PatchRemoveInstruction": PatchRemoveInstruction,
    "PatchSensitiveColumnDetails": PatchSensitiveColumnDetails,
    "PreserveOriginalDataFormatEntry": PreserveOriginalDataFormatEntry,
    "PrivateEndpoint": PrivateEndpoint,
    "ProfileDetails": ProfileDetails,
    "ProvisionAuditConditions": ProvisionAuditConditions,
    "ProvisionAuditPolicyDetails": ProvisionAuditPolicyDetails,
    "RandomDateFormatEntry": RandomDateFormatEntry,
    "RandomDecimalNumberFormatEntry": RandomDecimalNumberFormatEntry,
    "RandomDigitsFormatEntry": RandomDigitsFormatEntry,
    "RandomListFormatEntry": RandomListFormatEntry,
    "RandomNumberFormatEntry": RandomNumberFormatEntry,
    "RandomStringFormatEntry": RandomStringFormatEntry,
    "RandomSubstitutionFormatEntry": RandomSubstitutionFormatEntry,
    "References": References,
    "RegularExpressionFormatEntry": RegularExpressionFormatEntry,
    "Report": Report,
    "ReportCollection": ReportCollection,
    "ReportDefinition": ReportDefinition,
    "ReportDefinitionCollection": ReportDefinitionCollection,
    "ReportDefinitionSummary": ReportDefinitionSummary,
    "ReportSummary": ReportSummary,
    "RoleSummary": RoleSummary,
    "RunSecurityAssessmentDetails": RunSecurityAssessmentDetails,
    "RunUserAssessmentDetails": RunUserAssessmentDetails,
    "SQLExpressionFormatEntry": SQLExpressionFormatEntry,
    "SchemaSummary": SchemaSummary,
    "SectionStatistics": SectionStatistics,
    "SecurityAssessment": SecurityAssessment,
    "SecurityAssessmentBaseLineDetails": SecurityAssessmentBaseLineDetails,
    "SecurityAssessmentComparison": SecurityAssessmentComparison,
    "SecurityAssessmentComparisonPerTarget": SecurityAssessmentComparisonPerTarget,
    "SecurityAssessmentStatistics": SecurityAssessmentStatistics,
    "SecurityAssessmentSummary": SecurityAssessmentSummary,
    "SensitiveCategory": SensitiveCategory,
    "SensitiveColumn": SensitiveColumn,
    "SensitiveColumnCollection": SensitiveColumnCollection,
    "SensitiveColumnSummary": SensitiveColumnSummary,
    "SensitiveDataModel": SensitiveDataModel,
    "SensitiveDataModelCollection": SensitiveDataModelCollection,
    "SensitiveDataModelSummary": SensitiveDataModelSummary,
    "SensitiveType": SensitiveType,
    "SensitiveTypeCollection": SensitiveTypeCollection,
    "SensitiveTypePattern": SensitiveTypePattern,
    "SensitiveTypeSummary": SensitiveTypeSummary,
    "ShuffleFormatEntry": ShuffleFormatEntry,
    "StartAuditTrailDetails": StartAuditTrailDetails,
    "SubstringFormatEntry": SubstringFormatEntry,
    "Summary": Summary,
    "TableSummary": TableSummary,
    "TargetAlertPolicyAssociation": TargetAlertPolicyAssociation,
    "TargetAlertPolicyAssociationCollection": TargetAlertPolicyAssociationCollection,
    "TargetAlertPolicyAssociationSummary": TargetAlertPolicyAssociationSummary,
    "TargetDatabase": TargetDatabase,
    "TargetDatabaseSummary": TargetDatabaseSummary,
    "TlsConfig": TlsConfig,
    "TruncateTableFormatEntry": TruncateTableFormatEntry,
    "UDFFormatEntry": UDFFormatEntry,
    "UpdateAlertDetails": UpdateAlertDetails,
    "UpdateAlertPolicyRuleDetails": UpdateAlertPolicyRuleDetails,
    "UpdateAuditArchiveRetrievalDetails": UpdateAuditArchiveRetrievalDetails,
    "UpdateAuditPolicyDetails": UpdateAuditPolicyDetails,
    "UpdateAuditProfileDetails": UpdateAuditProfileDetails,
    "UpdateAuditTrailDetails": UpdateAuditTrailDetails,
    "UpdateColumnSourceDetails": UpdateColumnSourceDetails,
    "UpdateColumnSourceSdmDetails": UpdateColumnSourceSdmDetails,
    "UpdateColumnSourceTargetDetails": UpdateColumnSourceTargetDetails,
    "UpdateDataSafePrivateEndpointDetails": UpdateDataSafePrivateEndpointDetails,
    "UpdateLibraryMaskingFormatDetails": UpdateLibraryMaskingFormatDetails,
    "UpdateMaskingColumnDetails": UpdateMaskingColumnDetails,
    "UpdateMaskingPolicyDetails": UpdateMaskingPolicyDetails,
    "UpdateOnPremConnectorDetails": UpdateOnPremConnectorDetails,
    "UpdateOnPremConnectorWalletDetails": UpdateOnPremConnectorWalletDetails,
    "UpdateReportDefinitionDetails": UpdateReportDefinitionDetails,
    "UpdateSecurityAssessmentDetails": UpdateSecurityAssessmentDetails,
    "UpdateSensitiveCategoryDetails": UpdateSensitiveCategoryDetails,
    "UpdateSensitiveColumnDetails": UpdateSensitiveColumnDetails,
    "UpdateSensitiveDataModelDetails": UpdateSensitiveDataModelDetails,
    "UpdateSensitiveTypeDetails": UpdateSensitiveTypeDetails,
    "UpdateSensitiveTypePatternDetails": UpdateSensitiveTypePatternDetails,
    "UpdateTargetAlertPolicyAssociationDetails": UpdateTargetAlertPolicyAssociationDetails,
    "UpdateTargetDatabaseDetails": UpdateTargetDatabaseDetails,
    "UpdateUserAssessmentDetails": UpdateUserAssessmentDetails,
    "UserAggregation": UserAggregation,
    "UserAssessment": UserAssessment,
    "UserAssessmentBaseLineDetails": UserAssessmentBaseLineDetails,
    "UserAssessmentComparison": UserAssessmentComparison,
    "UserAssessmentSummary": UserAssessmentSummary,
    "UserDetails": UserDetails,
    "UserSummary": UserSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InvoiceSummary(object):
    """
    Invoice details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InvoiceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param spm_invoice_number:
            The value to assign to the spm_invoice_number property of this InvoiceSummary.
        :type spm_invoice_number: str

        :param ar_invoices:
            The value to assign to the ar_invoices property of this InvoiceSummary.
        :type ar_invoices: str

        :param bill_to_customer:
            The value to assign to the bill_to_customer property of this InvoiceSummary.
        :type bill_to_customer: oci.onesubscription.models.InvoicingBusinessPartner

        :param bill_to_contact:
            The value to assign to the bill_to_contact property of this InvoiceSummary.
        :type bill_to_contact: oci.onesubscription.models.InvoicingUser

        :param bill_to_address:
            The value to assign to the bill_to_address property of this InvoiceSummary.
        :type bill_to_address: oci.onesubscription.models.InvoicingAddress

        :param payment_method:
            The value to assign to the payment_method property of this InvoiceSummary.
        :type payment_method: str

        :param payment_term:
            The value to assign to the payment_term property of this InvoiceSummary.
        :type payment_term: oci.onesubscription.models.InvoicingPaymentTerm

        :param receipt_method:
            The value to assign to the receipt_method property of this InvoiceSummary.
        :type receipt_method: str

        :param currency:
            The value to assign to the currency property of this InvoiceSummary.
        :type currency: oci.onesubscription.models.InvoicingCurrency

        :param organization:
            The value to assign to the organization property of this InvoiceSummary.
        :type organization: oci.onesubscription.models.InvoicingOrganization

        :param type:
            The value to assign to the type property of this InvoiceSummary.
        :type type: str

        :param status:
            The value to assign to the status property of this InvoiceSummary.
        :type status: str

        :param subscription_number:
            The value to assign to the subscription_number property of this InvoiceSummary.
        :type subscription_number: str

        :param time_invoice_date:
            The value to assign to the time_invoice_date property of this InvoiceSummary.
        :type time_invoice_date: datetime

        :param time_created:
            The value to assign to the time_created property of this InvoiceSummary.
        :type time_created: datetime

        :param created_by:
            The value to assign to the created_by property of this InvoiceSummary.
        :type created_by: str

        :param time_updated:
            The value to assign to the time_updated property of this InvoiceSummary.
        :type time_updated: datetime

        :param updated_by:
            The value to assign to the updated_by property of this InvoiceSummary.
        :type updated_by: str

        :param invoice_lines:
            The value to assign to the invoice_lines property of this InvoiceSummary.
        :type invoice_lines: list[oci.onesubscription.models.InvoiceLineSummary]

        """
        self.swagger_types = {
            'spm_invoice_number': 'str',
            'ar_invoices': 'str',
            'bill_to_customer': 'InvoicingBusinessPartner',
            'bill_to_contact': 'InvoicingUser',
            'bill_to_address': 'InvoicingAddress',
            'payment_method': 'str',
            'payment_term': 'InvoicingPaymentTerm',
            'receipt_method': 'str',
            'currency': 'InvoicingCurrency',
            'organization': 'InvoicingOrganization',
            'type': 'str',
            'status': 'str',
            'subscription_number': 'str',
            'time_invoice_date': 'datetime',
            'time_created': 'datetime',
            'created_by': 'str',
            'time_updated': 'datetime',
            'updated_by': 'str',
            'invoice_lines': 'list[InvoiceLineSummary]'
        }

        self.attribute_map = {
            'spm_invoice_number': 'spmInvoiceNumber',
            'ar_invoices': 'arInvoices',
            'bill_to_customer': 'billToCustomer',
            'bill_to_contact': 'billToContact',
            'bill_to_address': 'billToAddress',
            'payment_method': 'paymentMethod',
            'payment_term': 'paymentTerm',
            'receipt_method': 'receiptMethod',
            'currency': 'currency',
            'organization': 'organization',
            'type': 'type',
            'status': 'status',
            'subscription_number': 'subscriptionNumber',
            'time_invoice_date': 'timeInvoiceDate',
            'time_created': 'timeCreated',
            'created_by': 'createdBy',
            'time_updated': 'timeUpdated',
            'updated_by': 'updatedBy',
            'invoice_lines': 'invoiceLines'
        }

        self._spm_invoice_number = None
        self._ar_invoices = None
        self._bill_to_customer = None
        self._bill_to_contact = None
        self._bill_to_address = None
        self._payment_method = None
        self._payment_term = None
        self._receipt_method = None
        self._currency = None
        self._organization = None
        self._type = None
        self._status = None
        self._subscription_number = None
        self._time_invoice_date = None
        self._time_created = None
        self._created_by = None
        self._time_updated = None
        self._updated_by = None
        self._invoice_lines = None

    @property
    def spm_invoice_number(self):
        """
        **[Required]** Gets the spm_invoice_number of this InvoiceSummary.
        SPM Document Number is an functional identifier for invoice in SPM


        :return: The spm_invoice_number of this InvoiceSummary.
        :rtype: str
        """
        return self._spm_invoice_number

    @spm_invoice_number.setter
    def spm_invoice_number(self, spm_invoice_number):
        """
        Sets the spm_invoice_number of this InvoiceSummary.
        SPM Document Number is an functional identifier for invoice in SPM


        :param spm_invoice_number: The spm_invoice_number of this InvoiceSummary.
        :type: str
        """
        self._spm_invoice_number = spm_invoice_number

    @property
    def ar_invoices(self):
        """
        Gets the ar_invoices of this InvoiceSummary.
        AR Invoice Numbers comma separated under one invoice


        :return: The ar_invoices of this InvoiceSummary.
        :rtype: str
        """
        return self._ar_invoices

    @ar_invoices.setter
    def ar_invoices(self, ar_invoices):
        """
        Sets the ar_invoices of this InvoiceSummary.
        AR Invoice Numbers comma separated under one invoice


        :param ar_invoices: The ar_invoices of this InvoiceSummary.
        :type: str
        """
        self._ar_invoices = ar_invoices

    @property
    def bill_to_customer(self):
        """
        **[Required]** Gets the bill_to_customer of this InvoiceSummary.

        :return: The bill_to_customer of this InvoiceSummary.
        :rtype: oci.onesubscription.models.InvoicingBusinessPartner
        """
        return self._bill_to_customer

    @bill_to_customer.setter
    def bill_to_customer(self, bill_to_customer):
        """
        Sets the bill_to_customer of this InvoiceSummary.

        :param bill_to_customer: The bill_to_customer of this InvoiceSummary.
        :type: oci.onesubscription.models.InvoicingBusinessPartner
        """
        self._bill_to_customer = bill_to_customer

    @property
    def bill_to_contact(self):
        """
        **[Required]** Gets the bill_to_contact of this InvoiceSummary.

        :return: The bill_to_contact of this InvoiceSummary.
        :rtype: oci.onesubscription.models.InvoicingUser
        """
        return self._bill_to_contact

    @bill_to_contact.setter
    def bill_to_contact(self, bill_to_contact):
        """
        Sets the bill_to_contact of this InvoiceSummary.

        :param bill_to_contact: The bill_to_contact of this InvoiceSummary.
        :type: oci.onesubscription.models.InvoicingUser
        """
        self._bill_to_contact = bill_to_contact

    @property
    def bill_to_address(self):
        """
        **[Required]** Gets the bill_to_address of this InvoiceSummary.

        :return: The bill_to_address of this InvoiceSummary.
        :rtype: oci.onesubscription.models.InvoicingAddress
        """
        return self._bill_to_address

    @bill_to_address.setter
    def bill_to_address(self, bill_to_address):
        """
        Sets the bill_to_address of this InvoiceSummary.

        :param bill_to_address: The bill_to_address of this InvoiceSummary.
        :type: oci.onesubscription.models.InvoicingAddress
        """
        self._bill_to_address = bill_to_address

    @property
    def payment_method(self):
        """
        **[Required]** Gets the payment_method of this InvoiceSummary.
        Payment Method


        :return: The payment_method of this InvoiceSummary.
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """
        Sets the payment_method of this InvoiceSummary.
        Payment Method


        :param payment_method: The payment_method of this InvoiceSummary.
        :type: str
        """
        self._payment_method = payment_method

    @property
    def payment_term(self):
        """
        **[Required]** Gets the payment_term of this InvoiceSummary.

        :return: The payment_term of this InvoiceSummary.
        :rtype: oci.onesubscription.models.InvoicingPaymentTerm
        """
        return self._payment_term

    @payment_term.setter
    def payment_term(self, payment_term):
        """
        Sets the payment_term of this InvoiceSummary.

        :param payment_term: The payment_term of this InvoiceSummary.
        :type: oci.onesubscription.models.InvoicingPaymentTerm
        """
        self._payment_term = payment_term

    @property
    def receipt_method(self):
        """
        Gets the receipt_method of this InvoiceSummary.
        Receipt Method of Payment Mode


        :return: The receipt_method of this InvoiceSummary.
        :rtype: str
        """
        return self._receipt_method

    @receipt_method.setter
    def receipt_method(self, receipt_method):
        """
        Sets the receipt_method of this InvoiceSummary.
        Receipt Method of Payment Mode


        :param receipt_method: The receipt_method of this InvoiceSummary.
        :type: str
        """
        self._receipt_method = receipt_method

    @property
    def currency(self):
        """
        **[Required]** Gets the currency of this InvoiceSummary.

        :return: The currency of this InvoiceSummary.
        :rtype: oci.onesubscription.models.InvoicingCurrency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this InvoiceSummary.

        :param currency: The currency of this InvoiceSummary.
        :type: oci.onesubscription.models.InvoicingCurrency
        """
        self._currency = currency

    @property
    def organization(self):
        """
        **[Required]** Gets the organization of this InvoiceSummary.

        :return: The organization of this InvoiceSummary.
        :rtype: oci.onesubscription.models.InvoicingOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this InvoiceSummary.

        :param organization: The organization of this InvoiceSummary.
        :type: oci.onesubscription.models.InvoicingOrganization
        """
        self._organization = organization

    @property
    def type(self):
        """
        **[Required]** Gets the type of this InvoiceSummary.
        Document Type in SPM like SPM Invoice,SPM Credit Memo etc.,


        :return: The type of this InvoiceSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this InvoiceSummary.
        Document Type in SPM like SPM Invoice,SPM Credit Memo etc.,


        :param type: The type of this InvoiceSummary.
        :type: str
        """
        self._type = type

    @property
    def status(self):
        """
        **[Required]** Gets the status of this InvoiceSummary.
        Document Status in SPM which depicts current state of invoice


        :return: The status of this InvoiceSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this InvoiceSummary.
        Document Status in SPM which depicts current state of invoice


        :param status: The status of this InvoiceSummary.
        :type: str
        """
        self._status = status

    @property
    def subscription_number(self):
        """
        **[Required]** Gets the subscription_number of this InvoiceSummary.
        Invoice associated subscription plan number.


        :return: The subscription_number of this InvoiceSummary.
        :rtype: str
        """
        return self._subscription_number

    @subscription_number.setter
    def subscription_number(self, subscription_number):
        """
        Sets the subscription_number of this InvoiceSummary.
        Invoice associated subscription plan number.


        :param subscription_number: The subscription_number of this InvoiceSummary.
        :type: str
        """
        self._subscription_number = subscription_number

    @property
    def time_invoice_date(self):
        """
        **[Required]** Gets the time_invoice_date of this InvoiceSummary.
        Invoice Date


        :return: The time_invoice_date of this InvoiceSummary.
        :rtype: datetime
        """
        return self._time_invoice_date

    @time_invoice_date.setter
    def time_invoice_date(self, time_invoice_date):
        """
        Sets the time_invoice_date of this InvoiceSummary.
        Invoice Date


        :param time_invoice_date: The time_invoice_date of this InvoiceSummary.
        :type: datetime
        """
        self._time_invoice_date = time_invoice_date

    @property
    def time_created(self):
        """
        Gets the time_created of this InvoiceSummary.
        SPM Invocie creation date


        :return: The time_created of this InvoiceSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this InvoiceSummary.
        SPM Invocie creation date


        :param time_created: The time_created of this InvoiceSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def created_by(self):
        """
        Gets the created_by of this InvoiceSummary.
        User that executed SPM Invoice process


        :return: The created_by of this InvoiceSummary.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this InvoiceSummary.
        User that executed SPM Invoice process


        :param created_by: The created_by of this InvoiceSummary.
        :type: str
        """
        self._created_by = created_by

    @property
    def time_updated(self):
        """
        Gets the time_updated of this InvoiceSummary.
        SPM Invoice updated date


        :return: The time_updated of this InvoiceSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this InvoiceSummary.
        SPM Invoice updated date


        :param time_updated: The time_updated of this InvoiceSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def updated_by(self):
        """
        Gets the updated_by of this InvoiceSummary.
        User that updated SPM Invoice


        :return: The updated_by of this InvoiceSummary.
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """
        Sets the updated_by of this InvoiceSummary.
        User that updated SPM Invoice


        :param updated_by: The updated_by of this InvoiceSummary.
        :type: str
        """
        self._updated_by = updated_by

    @property
    def invoice_lines(self):
        """
        Gets the invoice_lines of this InvoiceSummary.
        Invoice Lines under particular invoice.


        :return: The invoice_lines of this InvoiceSummary.
        :rtype: list[oci.onesubscription.models.InvoiceLineSummary]
        """
        return self._invoice_lines

    @invoice_lines.setter
    def invoice_lines(self, invoice_lines):
        """
        Sets the invoice_lines of this InvoiceSummary.
        Invoice Lines under particular invoice.


        :param invoice_lines: The invoice_lines of this InvoiceSummary.
        :type: list[oci.onesubscription.models.InvoiceLineSummary]
        """
        self._invoice_lines = invoice_lines

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateBlocklistDetails(object):
    """
    The blocklist record details.
    """

    #: A constant which can be used with the operation property of a CreateBlocklistDetails.
    #: This constant has a value of "CREATE_FLEET"
    OPERATION_CREATE_FLEET = "CREATE_FLEET"

    #: A constant which can be used with the operation property of a CreateBlocklistDetails.
    #: This constant has a value of "DELETE_FLEET"
    OPERATION_DELETE_FLEET = "DELETE_FLEET"

    #: A constant which can be used with the operation property of a CreateBlocklistDetails.
    #: This constant has a value of "MOVE_FLEET"
    OPERATION_MOVE_FLEET = "MOVE_FLEET"

    #: A constant which can be used with the operation property of a CreateBlocklistDetails.
    #: This constant has a value of "UPDATE_FLEET"
    OPERATION_UPDATE_FLEET = "UPDATE_FLEET"

    #: A constant which can be used with the operation property of a CreateBlocklistDetails.
    #: This constant has a value of "UPDATE_FLEET_AGENT_CONFIGURATION"
    OPERATION_UPDATE_FLEET_AGENT_CONFIGURATION = "UPDATE_FLEET_AGENT_CONFIGURATION"

    #: A constant which can be used with the operation property of a CreateBlocklistDetails.
    #: This constant has a value of "DELETE_JAVA_INSTALLATION"
    OPERATION_DELETE_JAVA_INSTALLATION = "DELETE_JAVA_INSTALLATION"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateBlocklistDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target:
            The value to assign to the target property of this CreateBlocklistDetails.
        :type target: oci.jms.models.BlocklistTarget

        :param operation:
            The value to assign to the operation property of this CreateBlocklistDetails.
            Allowed values for this property are: "CREATE_FLEET", "DELETE_FLEET", "MOVE_FLEET", "UPDATE_FLEET", "UPDATE_FLEET_AGENT_CONFIGURATION", "DELETE_JAVA_INSTALLATION"
        :type operation: str

        :param reason:
            The value to assign to the reason property of this CreateBlocklistDetails.
        :type reason: str

        """
        self.swagger_types = {
            'target': 'BlocklistTarget',
            'operation': 'str',
            'reason': 'str'
        }

        self.attribute_map = {
            'target': 'target',
            'operation': 'operation',
            'reason': 'reason'
        }

        self._target = None
        self._operation = None
        self._reason = None

    @property
    def target(self):
        """
        **[Required]** Gets the target of this CreateBlocklistDetails.

        :return: The target of this CreateBlocklistDetails.
        :rtype: oci.jms.models.BlocklistTarget
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this CreateBlocklistDetails.

        :param target: The target of this CreateBlocklistDetails.
        :type: oci.jms.models.BlocklistTarget
        """
        self._target = target

    @property
    def operation(self):
        """
        **[Required]** Gets the operation of this CreateBlocklistDetails.
        The operation type

        Allowed values for this property are: "CREATE_FLEET", "DELETE_FLEET", "MOVE_FLEET", "UPDATE_FLEET", "UPDATE_FLEET_AGENT_CONFIGURATION", "DELETE_JAVA_INSTALLATION"


        :return: The operation of this CreateBlocklistDetails.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this CreateBlocklistDetails.
        The operation type


        :param operation: The operation of this CreateBlocklistDetails.
        :type: str
        """
        allowed_values = ["CREATE_FLEET", "DELETE_FLEET", "MOVE_FLEET", "UPDATE_FLEET", "UPDATE_FLEET_AGENT_CONFIGURATION", "DELETE_JAVA_INSTALLATION"]
        if not value_allowed_none_or_none_sentinel(operation, allowed_values):
            raise ValueError(
                "Invalid value for `operation`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._operation = operation

    @property
    def reason(self):
        """
        Gets the reason of this CreateBlocklistDetails.
        The reason for why the operation is blocklisted


        :return: The reason of this CreateBlocklistDetails.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this CreateBlocklistDetails.
        The reason for why the operation is blocklisted


        :param reason: The reason of this CreateBlocklistDetails.
        :type: str
        """
        self._reason = reason

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiscoveryJobLogSummary(object):
    """
    Log of a specific job
    """

    #: A constant which can be used with the log_type property of a DiscoveryJobLogSummary.
    #: This constant has a value of "INFO"
    LOG_TYPE_INFO = "INFO"

    #: A constant which can be used with the log_type property of a DiscoveryJobLogSummary.
    #: This constant has a value of "WARNING"
    LOG_TYPE_WARNING = "WARNING"

    #: A constant which can be used with the log_type property of a DiscoveryJobLogSummary.
    #: This constant has a value of "ERROR"
    LOG_TYPE_ERROR = "ERROR"

    #: A constant which can be used with the log_type property of a DiscoveryJobLogSummary.
    #: This constant has a value of "SUCCESS"
    LOG_TYPE_SUCCESS = "SUCCESS"

    def __init__(self, **kwargs):
        """
        Initializes a new DiscoveryJobLogSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DiscoveryJobLogSummary.
        :type id: str

        :param log_type:
            The value to assign to the log_type property of this DiscoveryJobLogSummary.
            Allowed values for this property are: "INFO", "WARNING", "ERROR", "SUCCESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type log_type: str

        :param log_message:
            The value to assign to the log_message property of this DiscoveryJobLogSummary.
        :type log_message: str

        :param time_created:
            The value to assign to the time_created property of this DiscoveryJobLogSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'log_type': 'str',
            'log_message': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'log_type': 'logType',
            'log_message': 'logMessage',
            'time_created': 'timeCreated'
        }

        self._id = None
        self._log_type = None
        self._log_message = None
        self._time_created = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DiscoveryJobLogSummary.
        The OCID of Discovery job


        :return: The id of this DiscoveryJobLogSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DiscoveryJobLogSummary.
        The OCID of Discovery job


        :param id: The id of this DiscoveryJobLogSummary.
        :type: str
        """
        self._id = id

    @property
    def log_type(self):
        """
        **[Required]** Gets the log_type of this DiscoveryJobLogSummary.
        Type of log (INFO, WARNING, ERROR or SUCCESS)

        Allowed values for this property are: "INFO", "WARNING", "ERROR", "SUCCESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The log_type of this DiscoveryJobLogSummary.
        :rtype: str
        """
        return self._log_type

    @log_type.setter
    def log_type(self, log_type):
        """
        Sets the log_type of this DiscoveryJobLogSummary.
        Type of log (INFO, WARNING, ERROR or SUCCESS)


        :param log_type: The log_type of this DiscoveryJobLogSummary.
        :type: str
        """
        allowed_values = ["INFO", "WARNING", "ERROR", "SUCCESS"]
        if not value_allowed_none_or_none_sentinel(log_type, allowed_values):
            log_type = 'UNKNOWN_ENUM_VALUE'
        self._log_type = log_type

    @property
    def log_message(self):
        """
        **[Required]** Gets the log_message of this DiscoveryJobLogSummary.
        Log message


        :return: The log_message of this DiscoveryJobLogSummary.
        :rtype: str
        """
        return self._log_message

    @log_message.setter
    def log_message(self, log_message):
        """
        Sets the log_message of this DiscoveryJobLogSummary.
        Log message


        :param log_message: The log_message of this DiscoveryJobLogSummary.
        :type: str
        """
        self._log_message = log_message

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DiscoveryJobLogSummary.
        Time the Job log was created


        :return: The time_created of this DiscoveryJobLogSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DiscoveryJobLogSummary.
        Time the Job log was created


        :param time_created: The time_created of this DiscoveryJobLogSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExecuteOperationJob(object):
    """
    Response of executeOperationJob.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ExecuteOperationJob object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation_status:
            The value to assign to the operation_status property of this ExecuteOperationJob.
        :type operation_status: str

        :param error_message:
            The value to assign to the error_message property of this ExecuteOperationJob.
        :type error_message: str

        :param operation_name:
            The value to assign to the operation_name property of this ExecuteOperationJob.
        :type operation_name: str

        :param out_params:
            The value to assign to the out_params property of this ExecuteOperationJob.
        :type out_params: list[str]

        :param operation_result:
            The value to assign to the operation_result property of this ExecuteOperationJob.
        :type operation_result: list[oci.data_connectivity.models.OperationExecResult]

        """
        self.swagger_types = {
            'operation_status': 'str',
            'error_message': 'str',
            'operation_name': 'str',
            'out_params': 'list[str]',
            'operation_result': 'list[OperationExecResult]'
        }

        self.attribute_map = {
            'operation_status': 'operationStatus',
            'error_message': 'errorMessage',
            'operation_name': 'operationName',
            'out_params': 'outParams',
            'operation_result': 'operationResult'
        }

        self._operation_status = None
        self._error_message = None
        self._operation_name = None
        self._out_params = None
        self._operation_result = None

    @property
    def operation_status(self):
        """
        **[Required]** Gets the operation_status of this ExecuteOperationJob.
        Status of the operation job for all sets of input.


        :return: The operation_status of this ExecuteOperationJob.
        :rtype: str
        """
        return self._operation_status

    @operation_status.setter
    def operation_status(self, operation_status):
        """
        Sets the operation_status of this ExecuteOperationJob.
        Status of the operation job for all sets of input.


        :param operation_status: The operation_status of this ExecuteOperationJob.
        :type: str
        """
        self._operation_status = operation_status

    @property
    def error_message(self):
        """
        Gets the error_message of this ExecuteOperationJob.
        Error message, if whole operation is failed.


        :return: The error_message of this ExecuteOperationJob.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this ExecuteOperationJob.
        Error message, if whole operation is failed.


        :param error_message: The error_message of this ExecuteOperationJob.
        :type: str
        """
        self._error_message = error_message

    @property
    def operation_name(self):
        """
        Gets the operation_name of this ExecuteOperationJob.
        Name of the operation.


        :return: The operation_name of this ExecuteOperationJob.
        :rtype: str
        """
        return self._operation_name

    @operation_name.setter
    def operation_name(self, operation_name):
        """
        Sets the operation_name of this ExecuteOperationJob.
        Name of the operation.


        :param operation_name: The operation_name of this ExecuteOperationJob.
        :type: str
        """
        self._operation_name = operation_name

    @property
    def out_params(self):
        """
        Gets the out_params of this ExecuteOperationJob.
        List of names of OUT/INOUT params.


        :return: The out_params of this ExecuteOperationJob.
        :rtype: list[str]
        """
        return self._out_params

    @out_params.setter
    def out_params(self, out_params):
        """
        Sets the out_params of this ExecuteOperationJob.
        List of names of OUT/INOUT params.


        :param out_params: The out_params of this ExecuteOperationJob.
        :type: list[str]
        """
        self._out_params = out_params

    @property
    def operation_result(self):
        """
        **[Required]** Gets the operation_result of this ExecuteOperationJob.
        List of operation execution result for each input set.


        :return: The operation_result of this ExecuteOperationJob.
        :rtype: list[oci.data_connectivity.models.OperationExecResult]
        """
        return self._operation_result

    @operation_result.setter
    def operation_result(self, operation_result):
        """
        Sets the operation_result of this ExecuteOperationJob.
        List of operation execution result for each input set.


        :param operation_result: The operation_result of this ExecuteOperationJob.
        :type: list[oci.data_connectivity.models.OperationExecResult]
        """
        self._operation_result = operation_result

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReportDefinition(object):
    """
    Description of report definition.
    """

    #: A constant which can be used with the category property of a ReportDefinition.
    #: This constant has a value of "CUSTOM_REPORTS"
    CATEGORY_CUSTOM_REPORTS = "CUSTOM_REPORTS"

    #: A constant which can be used with the category property of a ReportDefinition.
    #: This constant has a value of "SUMMARY"
    CATEGORY_SUMMARY = "SUMMARY"

    #: A constant which can be used with the category property of a ReportDefinition.
    #: This constant has a value of "ACTIVITY_AUDITING"
    CATEGORY_ACTIVITY_AUDITING = "ACTIVITY_AUDITING"

    #: A constant which can be used with the data_source property of a ReportDefinition.
    #: This constant has a value of "EVENTS"
    DATA_SOURCE_EVENTS = "EVENTS"

    #: A constant which can be used with the data_source property of a ReportDefinition.
    #: This constant has a value of "ALERTS"
    DATA_SOURCE_ALERTS = "ALERTS"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinition.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinition.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinition.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinition.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinition.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new ReportDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this ReportDefinition.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ReportDefinition.
        :type id: str

        :param parent_id:
            The value to assign to the parent_id property of this ReportDefinition.
        :type parent_id: str

        :param category:
            The value to assign to the category property of this ReportDefinition.
            Allowed values for this property are: "CUSTOM_REPORTS", "SUMMARY", "ACTIVITY_AUDITING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        :param description:
            The value to assign to the description property of this ReportDefinition.
        :type description: str

        :param data_source:
            The value to assign to the data_source property of this ReportDefinition.
            Allowed values for this property are: "EVENTS", "ALERTS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_source: str

        :param is_seeded:
            The value to assign to the is_seeded property of this ReportDefinition.
        :type is_seeded: bool

        :param display_order:
            The value to assign to the display_order property of this ReportDefinition.
        :type display_order: int

        :param time_created:
            The value to assign to the time_created property of this ReportDefinition.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ReportDefinition.
        :type time_updated: datetime

        :param scim_filter:
            The value to assign to the scim_filter property of this ReportDefinition.
        :type scim_filter: str

        :param column_info:
            The value to assign to the column_info property of this ReportDefinition.
        :type column_info: list[oci.data_safe.models.Column]

        :param column_filters:
            The value to assign to the column_filters property of this ReportDefinition.
        :type column_filters: list[oci.data_safe.models.ColumnFilter]

        :param column_sortings:
            The value to assign to the column_sortings property of this ReportDefinition.
        :type column_sortings: list[oci.data_safe.models.ColumnSorting]

        :param summary:
            The value to assign to the summary property of this ReportDefinition.
        :type summary: list[oci.data_safe.models.Summary]

        :param compartment_id:
            The value to assign to the compartment_id property of this ReportDefinition.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ReportDefinition.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ReportDefinition.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ReportDefinition.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this ReportDefinition.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'id': 'str',
            'parent_id': 'str',
            'category': 'str',
            'description': 'str',
            'data_source': 'str',
            'is_seeded': 'bool',
            'display_order': 'int',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'scim_filter': 'str',
            'column_info': 'list[Column]',
            'column_filters': 'list[ColumnFilter]',
            'column_sortings': 'list[ColumnSorting]',
            'summary': 'list[Summary]',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'id': 'id',
            'parent_id': 'parentId',
            'category': 'category',
            'description': 'description',
            'data_source': 'dataSource',
            'is_seeded': 'isSeeded',
            'display_order': 'displayOrder',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'scim_filter': 'scimFilter',
            'column_info': 'columnInfo',
            'column_filters': 'columnFilters',
            'column_sortings': 'columnSortings',
            'summary': 'summary',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._display_name = None
        self._id = None
        self._parent_id = None
        self._category = None
        self._description = None
        self._data_source = None
        self._is_seeded = None
        self._display_order = None
        self._time_created = None
        self._time_updated = None
        self._scim_filter = None
        self._column_info = None
        self._column_filters = None
        self._column_sortings = None
        self._summary = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ReportDefinition.
        Name of the report definition.


        :return: The display_name of this ReportDefinition.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ReportDefinition.
        Name of the report definition.


        :param display_name: The display_name of this ReportDefinition.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ReportDefinition.
        The OCID of the report definition.


        :return: The id of this ReportDefinition.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ReportDefinition.
        The OCID of the report definition.


        :param id: The id of this ReportDefinition.
        :type: str
        """
        self._id = id

    @property
    def parent_id(self):
        """
        Gets the parent_id of this ReportDefinition.
        The OCID of the parent report definition. In the case of seeded report definition, this is same as definition OCID.


        :return: The parent_id of this ReportDefinition.
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """
        Sets the parent_id of this ReportDefinition.
        The OCID of the parent report definition. In the case of seeded report definition, this is same as definition OCID.


        :param parent_id: The parent_id of this ReportDefinition.
        :type: str
        """
        self._parent_id = parent_id

    @property
    def category(self):
        """
        Gets the category of this ReportDefinition.
        Specifies the name of the category that this report belongs to.

        Allowed values for this property are: "CUSTOM_REPORTS", "SUMMARY", "ACTIVITY_AUDITING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The category of this ReportDefinition.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this ReportDefinition.
        Specifies the name of the category that this report belongs to.


        :param category: The category of this ReportDefinition.
        :type: str
        """
        allowed_values = ["CUSTOM_REPORTS", "SUMMARY", "ACTIVITY_AUDITING"]
        if not value_allowed_none_or_none_sentinel(category, allowed_values):
            category = 'UNKNOWN_ENUM_VALUE'
        self._category = category

    @property
    def description(self):
        """
        Gets the description of this ReportDefinition.
        A description of the report definition.


        :return: The description of this ReportDefinition.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReportDefinition.
        A description of the report definition.


        :param description: The description of this ReportDefinition.
        :type: str
        """
        self._description = description

    @property
    def data_source(self):
        """
        Gets the data_source of this ReportDefinition.
        Specifies the name of a resource that provides data for the report. For example alerts, events.

        Allowed values for this property are: "EVENTS", "ALERTS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_source of this ReportDefinition.
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """
        Sets the data_source of this ReportDefinition.
        Specifies the name of a resource that provides data for the report. For example alerts, events.


        :param data_source: The data_source of this ReportDefinition.
        :type: str
        """
        allowed_values = ["EVENTS", "ALERTS"]
        if not value_allowed_none_or_none_sentinel(data_source, allowed_values):
            data_source = 'UNKNOWN_ENUM_VALUE'
        self._data_source = data_source

    @property
    def is_seeded(self):
        """
        Gets the is_seeded of this ReportDefinition.
        Signifies whether the definition is seeded or user defined. Values can either be 'true' or 'false'.


        :return: The is_seeded of this ReportDefinition.
        :rtype: bool
        """
        return self._is_seeded

    @is_seeded.setter
    def is_seeded(self, is_seeded):
        """
        Sets the is_seeded of this ReportDefinition.
        Signifies whether the definition is seeded or user defined. Values can either be 'true' or 'false'.


        :param is_seeded: The is_seeded of this ReportDefinition.
        :type: bool
        """
        self._is_seeded = is_seeded

    @property
    def display_order(self):
        """
        Gets the display_order of this ReportDefinition.
        Specifies how the report definitions are ordered in the display.


        :return: The display_order of this ReportDefinition.
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """
        Sets the display_order of this ReportDefinition.
        Specifies how the report definitions are ordered in the display.


        :param display_order: The display_order of this ReportDefinition.
        :type: int
        """
        self._display_order = display_order

    @property
    def time_created(self):
        """
        Gets the time_created of this ReportDefinition.
        Specifies the time at which the report definition was created.


        :return: The time_created of this ReportDefinition.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ReportDefinition.
        Specifies the time at which the report definition was created.


        :param time_created: The time_created of this ReportDefinition.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ReportDefinition.
        The date and time of the report definition update in Data Safe.


        :return: The time_updated of this ReportDefinition.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ReportDefinition.
        The date and time of the report definition update in Data Safe.


        :param time_updated: The time_updated of this ReportDefinition.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def scim_filter(self):
        """
        Gets the scim_filter of this ReportDefinition.
        Additional scim filters used to specialize the report.


        :return: The scim_filter of this ReportDefinition.
        :rtype: str
        """
        return self._scim_filter

    @scim_filter.setter
    def scim_filter(self, scim_filter):
        """
        Sets the scim_filter of this ReportDefinition.
        Additional scim filters used to specialize the report.


        :param scim_filter: The scim_filter of this ReportDefinition.
        :type: str
        """
        self._scim_filter = scim_filter

    @property
    def column_info(self):
        """
        Gets the column_info of this ReportDefinition.
        An array of column objects in the order (left to right) displayed in the report. A column object stores all information about a column, including the name displayed on the UI, corresponding field name in the data source, data type of the column, and column visibility (if the column is visible to the user).


        :return: The column_info of this ReportDefinition.
        :rtype: list[oci.data_safe.models.Column]
        """
        return self._column_info

    @column_info.setter
    def column_info(self, column_info):
        """
        Sets the column_info of this ReportDefinition.
        An array of column objects in the order (left to right) displayed in the report. A column object stores all information about a column, including the name displayed on the UI, corresponding field name in the data source, data type of the column, and column visibility (if the column is visible to the user).


        :param column_info: The column_info of this ReportDefinition.
        :type: list[oci.data_safe.models.Column]
        """
        self._column_info = column_info

    @property
    def column_filters(self):
        """
        Gets the column_filters of this ReportDefinition.
        An array of column filter objects. A column Filter object stores all information about a column filter including field name, an operator, one or more expressions, if the filter is enabled, or if the filter is hidden.


        :return: The column_filters of this ReportDefinition.
        :rtype: list[oci.data_safe.models.ColumnFilter]
        """
        return self._column_filters

    @column_filters.setter
    def column_filters(self, column_filters):
        """
        Sets the column_filters of this ReportDefinition.
        An array of column filter objects. A column Filter object stores all information about a column filter including field name, an operator, one or more expressions, if the filter is enabled, or if the filter is hidden.


        :param column_filters: The column_filters of this ReportDefinition.
        :type: list[oci.data_safe.models.ColumnFilter]
        """
        self._column_filters = column_filters

    @property
    def column_sortings(self):
        """
        Gets the column_sortings of this ReportDefinition.
        An array of column sorting objects. Each column sorting object stores the column name to be sorted and if the sorting is in ascending order; sorting is done by the first column in the array, then by the second column in the array, etc.


        :return: The column_sortings of this ReportDefinition.
        :rtype: list[oci.data_safe.models.ColumnSorting]
        """
        return self._column_sortings

    @column_sortings.setter
    def column_sortings(self, column_sortings):
        """
        Sets the column_sortings of this ReportDefinition.
        An array of column sorting objects. Each column sorting object stores the column name to be sorted and if the sorting is in ascending order; sorting is done by the first column in the array, then by the second column in the array, etc.


        :param column_sortings: The column_sortings of this ReportDefinition.
        :type: list[oci.data_safe.models.ColumnSorting]
        """
        self._column_sortings = column_sortings

    @property
    def summary(self):
        """
        Gets the summary of this ReportDefinition.
        An array of report summary objects in the order (left to right)  displayed in the report.  A  report summary object stores all information about summary of report to be displayed, including the name displayed on UI, the display order, corresponding group by and count of values, summary visibility (if the summary is visible to user).


        :return: The summary of this ReportDefinition.
        :rtype: list[oci.data_safe.models.Summary]
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this ReportDefinition.
        An array of report summary objects in the order (left to right)  displayed in the report.  A  report summary object stores all information about summary of report to be displayed, including the name displayed on UI, the display order, corresponding group by and count of values, summary visibility (if the summary is visible to user).


        :param summary: The summary of this ReportDefinition.
        :type: list[oci.data_safe.models.Summary]
        """
        self._summary = summary

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ReportDefinition.
        The OCID of the compartment containing the report definition.


        :return: The compartment_id of this ReportDefinition.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ReportDefinition.
        The OCID of the compartment containing the report definition.


        :param compartment_id: The compartment_id of this ReportDefinition.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ReportDefinition.
        The current state of the report.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ReportDefinition.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ReportDefinition.
        The current state of the report.


        :param lifecycle_state: The lifecycle_state of this ReportDefinition.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ReportDefinition.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ReportDefinition.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ReportDefinition.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ReportDefinition.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ReportDefinition.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ReportDefinition.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ReportDefinition.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ReportDefinition.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this ReportDefinition.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this ReportDefinition.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this ReportDefinition.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this ReportDefinition.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_channel_result import CreateChannelResult
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAppEventChannelResult(CreateChannelResult):
    """
    The configuration for an Application Event channel.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAppEventChannelResult object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.CreateAppEventChannelResult.type` attribute
        of this class is ``APPEVENT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CreateAppEventChannelResult.
        :type id: str

        :param name:
            The value to assign to the name property of this CreateAppEventChannelResult.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateAppEventChannelResult.
        :type description: str

        :param category:
            The value to assign to the category property of this CreateAppEventChannelResult.
            Allowed values for this property are: "AGENT", "APPLICATION", "BOT", "BOT_AS_AGENT", "SYSTEM", "EVENT"
        :type category: str

        :param type:
            The value to assign to the type property of this CreateAppEventChannelResult.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK"
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this CreateAppEventChannelResult.
        :type session_expiry_duration_in_milliseconds: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CreateAppEventChannelResult.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this CreateAppEventChannelResult.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this CreateAppEventChannelResult.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateAppEventChannelResult.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateAppEventChannelResult.
        :type defined_tags: dict(str, dict(str, object))

        :param secret_key:
            The value to assign to the secret_key property of this CreateAppEventChannelResult.
        :type secret_key: str

        :param outbound_url:
            The value to assign to the outbound_url property of this CreateAppEventChannelResult.
        :type outbound_url: str

        :param event_sink_bot_ids:
            The value to assign to the event_sink_bot_ids property of this CreateAppEventChannelResult.
        :type event_sink_bot_ids: list[str]

        :param webhook_url:
            The value to assign to the webhook_url property of this CreateAppEventChannelResult.
        :type webhook_url: str

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'category': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'secret_key': 'str',
            'outbound_url': 'str',
            'event_sink_bot_ids': 'list[str]',
            'webhook_url': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'category': 'category',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'secret_key': 'secretKey',
            'outbound_url': 'outboundUrl',
            'event_sink_bot_ids': 'eventSinkBotIds',
            'webhook_url': 'webhookUrl'
        }

        self._id = None
        self._name = None
        self._description = None
        self._category = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None
        self._secret_key = None
        self._outbound_url = None
        self._event_sink_bot_ids = None
        self._webhook_url = None
        self._type = 'APPEVENT'

    @property
    def secret_key(self):
        """
        **[Required]** Gets the secret_key of this CreateAppEventChannelResult.
        The secret key used to verify the authenticity of received messages.
        This is only returned this once.  If it is lost the keys will need to be rotated to generate a new key.


        :return: The secret_key of this CreateAppEventChannelResult.
        :rtype: str
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        """
        Sets the secret_key of this CreateAppEventChannelResult.
        The secret key used to verify the authenticity of received messages.
        This is only returned this once.  If it is lost the keys will need to be rotated to generate a new key.


        :param secret_key: The secret_key of this CreateAppEventChannelResult.
        :type: str
        """
        self._secret_key = secret_key

    @property
    def outbound_url(self):
        """
        **[Required]** Gets the outbound_url of this CreateAppEventChannelResult.
        The URL for sending errors and responses to.


        :return: The outbound_url of this CreateAppEventChannelResult.
        :rtype: str
        """
        return self._outbound_url

    @outbound_url.setter
    def outbound_url(self, outbound_url):
        """
        Sets the outbound_url of this CreateAppEventChannelResult.
        The URL for sending errors and responses to.


        :param outbound_url: The outbound_url of this CreateAppEventChannelResult.
        :type: str
        """
        self._outbound_url = outbound_url

    @property
    def event_sink_bot_ids(self):
        """
        Gets the event_sink_bot_ids of this CreateAppEventChannelResult.
        The IDs of the Skills and Digital Assistants that the Channel is routed to.


        :return: The event_sink_bot_ids of this CreateAppEventChannelResult.
        :rtype: list[str]
        """
        return self._event_sink_bot_ids

    @event_sink_bot_ids.setter
    def event_sink_bot_ids(self, event_sink_bot_ids):
        """
        Sets the event_sink_bot_ids of this CreateAppEventChannelResult.
        The IDs of the Skills and Digital Assistants that the Channel is routed to.


        :param event_sink_bot_ids: The event_sink_bot_ids of this CreateAppEventChannelResult.
        :type: list[str]
        """
        self._event_sink_bot_ids = event_sink_bot_ids

    @property
    def webhook_url(self):
        """
        **[Required]** Gets the webhook_url of this CreateAppEventChannelResult.
        The URL to use to send messages to this channel.
        This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.


        :return: The webhook_url of this CreateAppEventChannelResult.
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """
        Sets the webhook_url of this CreateAppEventChannelResult.
        The URL to use to send messages to this channel.
        This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.


        :param webhook_url: The webhook_url of this CreateAppEventChannelResult.
        :type: str
        """
        self._webhook_url = webhook_url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_config_details import CreateConfigDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateMetricGroupDetails(CreateConfigDetails):
    """
    A metric group defines a set of metrics to collect from a span. It uses a span filter to specify which spans to
    process. The set is then published to a namespace, which is a product level subdivision of metrics.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateMetricGroupDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.apm_config.models.CreateMetricGroupDetails.config_type` attribute
        of this class is ``METRIC_GROUP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_type:
            The value to assign to the config_type property of this CreateMetricGroupDetails.
            Allowed values for this property are: "SPAN_FILTER", "METRIC_GROUP", "APDEX", "OPTIONS"
        :type config_type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateMetricGroupDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateMetricGroupDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateMetricGroupDetails.
        :type display_name: str

        :param filter_id:
            The value to assign to the filter_id property of this CreateMetricGroupDetails.
        :type filter_id: str

        :param namespace:
            The value to assign to the namespace property of this CreateMetricGroupDetails.
        :type namespace: str

        :param dimensions:
            The value to assign to the dimensions property of this CreateMetricGroupDetails.
        :type dimensions: list[oci.apm_config.models.Dimension]

        :param metrics:
            The value to assign to the metrics property of this CreateMetricGroupDetails.
        :type metrics: list[oci.apm_config.models.Metric]

        """
        self.swagger_types = {
            'config_type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'filter_id': 'str',
            'namespace': 'str',
            'dimensions': 'list[Dimension]',
            'metrics': 'list[Metric]'
        }

        self.attribute_map = {
            'config_type': 'configType',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'filter_id': 'filterId',
            'namespace': 'namespace',
            'dimensions': 'dimensions',
            'metrics': 'metrics'
        }

        self._config_type = None
        self._freeform_tags = None
        self._defined_tags = None
        self._display_name = None
        self._filter_id = None
        self._namespace = None
        self._dimensions = None
        self._metrics = None
        self._config_type = 'METRIC_GROUP'

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateMetricGroupDetails.
        The name by which a configuration entity is displayed to the end user.


        :return: The display_name of this CreateMetricGroupDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateMetricGroupDetails.
        The name by which a configuration entity is displayed to the end user.


        :param display_name: The display_name of this CreateMetricGroupDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def filter_id(self):
        """
        **[Required]** Gets the filter_id of this CreateMetricGroupDetails.
        The `OCID`__ of a Span Filter. The filterId is mandatory for the creation
        of MetricGroups. A filterId is generated when a Span Filter is created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The filter_id of this CreateMetricGroupDetails.
        :rtype: str
        """
        return self._filter_id

    @filter_id.setter
    def filter_id(self, filter_id):
        """
        Sets the filter_id of this CreateMetricGroupDetails.
        The `OCID`__ of a Span Filter. The filterId is mandatory for the creation
        of MetricGroups. A filterId is generated when a Span Filter is created.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param filter_id: The filter_id of this CreateMetricGroupDetails.
        :type: str
        """
        self._filter_id = filter_id

    @property
    def namespace(self):
        """
        Gets the namespace of this CreateMetricGroupDetails.
        The namespace to which the metrics are published. It must be one of several predefined namespaces.


        :return: The namespace of this CreateMetricGroupDetails.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this CreateMetricGroupDetails.
        The namespace to which the metrics are published. It must be one of several predefined namespaces.


        :param namespace: The namespace of this CreateMetricGroupDetails.
        :type: str
        """
        self._namespace = namespace

    @property
    def dimensions(self):
        """
        Gets the dimensions of this CreateMetricGroupDetails.
        A list of dimensions for the metric. This variable should not be used.


        :return: The dimensions of this CreateMetricGroupDetails.
        :rtype: list[oci.apm_config.models.Dimension]
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this CreateMetricGroupDetails.
        A list of dimensions for the metric. This variable should not be used.


        :param dimensions: The dimensions of this CreateMetricGroupDetails.
        :type: list[oci.apm_config.models.Dimension]
        """
        self._dimensions = dimensions

    @property
    def metrics(self):
        """
        **[Required]** Gets the metrics of this CreateMetricGroupDetails.
        The list of metrics in this group.


        :return: The metrics of this CreateMetricGroupDetails.
        :rtype: list[oci.apm_config.models.Metric]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this CreateMetricGroupDetails.
        The list of metrics in this group.


        :param metrics: The metrics of this CreateMetricGroupDetails.
        :type: list[oci.apm_config.models.Metric]
        """
        self._metrics = metrics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .validate_database_tools_connection_result import ValidateDatabaseToolsConnectionResult
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ValidateDatabaseToolsConnectionMySqlResult(ValidateDatabaseToolsConnectionResult):
    """
    Connection validaton result for the MySQL Server.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ValidateDatabaseToolsConnectionMySqlResult object with values from keyword arguments. The default value of the :py:attr:`~oci.database_tools.models.ValidateDatabaseToolsConnectionMySqlResult.type` attribute
        of this class is ``MYSQL`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ValidateDatabaseToolsConnectionMySqlResult.
            Allowed values for this property are: "ORACLE_DATABASE", "MYSQL"
        :type type: str

        :param code:
            The value to assign to the code property of this ValidateDatabaseToolsConnectionMySqlResult.
        :type code: str

        :param message:
            The value to assign to the message property of this ValidateDatabaseToolsConnectionMySqlResult.
        :type message: str

        :param cause:
            The value to assign to the cause property of this ValidateDatabaseToolsConnectionMySqlResult.
        :type cause: str

        :param action:
            The value to assign to the action property of this ValidateDatabaseToolsConnectionMySqlResult.
        :type action: str

        :param database_name:
            The value to assign to the database_name property of this ValidateDatabaseToolsConnectionMySqlResult.
        :type database_name: str

        :param database_version:
            The value to assign to the database_version property of this ValidateDatabaseToolsConnectionMySqlResult.
        :type database_version: str

        """
        self.swagger_types = {
            'type': 'str',
            'code': 'str',
            'message': 'str',
            'cause': 'str',
            'action': 'str',
            'database_name': 'str',
            'database_version': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'code': 'code',
            'message': 'message',
            'cause': 'cause',
            'action': 'action',
            'database_name': 'databaseName',
            'database_version': 'databaseVersion'
        }

        self._type = None
        self._code = None
        self._message = None
        self._cause = None
        self._action = None
        self._database_name = None
        self._database_version = None
        self._type = 'MYSQL'

    @property
    def database_name(self):
        """
        Gets the database_name of this ValidateDatabaseToolsConnectionMySqlResult.
        The database name.


        :return: The database_name of this ValidateDatabaseToolsConnectionMySqlResult.
        :rtype: str
        """
        return self._database_name

    @database_name.setter
    def database_name(self, database_name):
        """
        Sets the database_name of this ValidateDatabaseToolsConnectionMySqlResult.
        The database name.


        :param database_name: The database_name of this ValidateDatabaseToolsConnectionMySqlResult.
        :type: str
        """
        self._database_name = database_name

    @property
    def database_version(self):
        """
        Gets the database_version of this ValidateDatabaseToolsConnectionMySqlResult.
        The database version.


        :return: The database_version of this ValidateDatabaseToolsConnectionMySqlResult.
        :rtype: str
        """
        return self._database_version

    @database_version.setter
    def database_version(self, database_version):
        """
        Sets the database_version of this ValidateDatabaseToolsConnectionMySqlResult.
        The database version.


        :param database_version: The database_version of this ValidateDatabaseToolsConnectionMySqlResult.
        :type: str
        """
        self._database_version = database_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostScanRecipe(object):
    """
    A host scan recipe (collection of host scanning configuration settings)
    """

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new HostScanRecipe object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this HostScanRecipe.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this HostScanRecipe.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this HostScanRecipe.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this HostScanRecipe.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this HostScanRecipe.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this HostScanRecipe.
        :type time_updated: datetime

        :param port_settings:
            The value to assign to the port_settings property of this HostScanRecipe.
        :type port_settings: oci.vulnerability_scanning.models.HostScanPortSettings

        :param agent_settings:
            The value to assign to the agent_settings property of this HostScanRecipe.
        :type agent_settings: oci.vulnerability_scanning.models.HostScanAgentSettings

        :param application_settings:
            The value to assign to the application_settings property of this HostScanRecipe.
        :type application_settings: oci.vulnerability_scanning.models.ApplicationScanSettings

        :param schedule:
            The value to assign to the schedule property of this HostScanRecipe.
        :type schedule: oci.vulnerability_scanning.models.Schedule

        :param freeform_tags:
            The value to assign to the freeform_tags property of this HostScanRecipe.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this HostScanRecipe.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this HostScanRecipe.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'port_settings': 'HostScanPortSettings',
            'agent_settings': 'HostScanAgentSettings',
            'application_settings': 'ApplicationScanSettings',
            'schedule': 'Schedule',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'port_settings': 'portSettings',
            'agent_settings': 'agentSettings',
            'application_settings': 'applicationSettings',
            'schedule': 'schedule',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._port_settings = None
        self._agent_settings = None
        self._application_settings = None
        self._schedule = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this HostScanRecipe.
        Unique identifier of the config that is immutable on creation


        :return: The id of this HostScanRecipe.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HostScanRecipe.
        Unique identifier of the config that is immutable on creation


        :param id: The id of this HostScanRecipe.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this HostScanRecipe.
        Recipe identifier, which can be renamed


        :return: The display_name of this HostScanRecipe.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this HostScanRecipe.
        Recipe identifier, which can be renamed


        :param display_name: The display_name of this HostScanRecipe.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this HostScanRecipe.
        Compartment ID of the scan recipe


        :return: The compartment_id of this HostScanRecipe.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this HostScanRecipe.
        Compartment ID of the scan recipe


        :param compartment_id: The compartment_id of this HostScanRecipe.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this HostScanRecipe.
        The current state of the config.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this HostScanRecipe.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this HostScanRecipe.
        The current state of the config.


        :param lifecycle_state: The lifecycle_state of this HostScanRecipe.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this HostScanRecipe.
        Date and time the recipe was created, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this HostScanRecipe.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this HostScanRecipe.
        Date and time the recipe was created, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this HostScanRecipe.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this HostScanRecipe.
        Date and time the recipe was last updated, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this HostScanRecipe.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this HostScanRecipe.
        Date and time the recipe was last updated, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this HostScanRecipe.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def port_settings(self):
        """
        **[Required]** Gets the port_settings of this HostScanRecipe.

        :return: The port_settings of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.HostScanPortSettings
        """
        return self._port_settings

    @port_settings.setter
    def port_settings(self, port_settings):
        """
        Sets the port_settings of this HostScanRecipe.

        :param port_settings: The port_settings of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.HostScanPortSettings
        """
        self._port_settings = port_settings

    @property
    def agent_settings(self):
        """
        **[Required]** Gets the agent_settings of this HostScanRecipe.

        :return: The agent_settings of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.HostScanAgentSettings
        """
        return self._agent_settings

    @agent_settings.setter
    def agent_settings(self, agent_settings):
        """
        Sets the agent_settings of this HostScanRecipe.

        :param agent_settings: The agent_settings of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.HostScanAgentSettings
        """
        self._agent_settings = agent_settings

    @property
    def application_settings(self):
        """
        Gets the application_settings of this HostScanRecipe.

        :return: The application_settings of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.ApplicationScanSettings
        """
        return self._application_settings

    @application_settings.setter
    def application_settings(self, application_settings):
        """
        Sets the application_settings of this HostScanRecipe.

        :param application_settings: The application_settings of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.ApplicationScanSettings
        """
        self._application_settings = application_settings

    @property
    def schedule(self):
        """
        **[Required]** Gets the schedule of this HostScanRecipe.

        :return: The schedule of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.Schedule
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this HostScanRecipe.

        :param schedule: The schedule of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.Schedule
        """
        self._schedule = schedule

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this HostScanRecipe.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this HostScanRecipe.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this HostScanRecipe.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this HostScanRecipe.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this HostScanRecipe.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this HostScanRecipe.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this HostScanRecipe.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this HostScanRecipe.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this HostScanRecipe.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this HostScanRecipe.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this HostScanRecipe.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this HostScanRecipe.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MigrationObjectSummary(object):
    """
    Database objects to include or exclude from migration
    """

    #: A constant which can be used with the object_status property of a MigrationObjectSummary.
    #: This constant has a value of "EXCLUDE"
    OBJECT_STATUS_EXCLUDE = "EXCLUDE"

    #: A constant which can be used with the object_status property of a MigrationObjectSummary.
    #: This constant has a value of "INCLUDE"
    OBJECT_STATUS_INCLUDE = "INCLUDE"

    def __init__(self, **kwargs):
        """
        Initializes a new MigrationObjectSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param owner:
            The value to assign to the owner property of this MigrationObjectSummary.
        :type owner: str

        :param object_name:
            The value to assign to the object_name property of this MigrationObjectSummary.
        :type object_name: str

        :param type:
            The value to assign to the type property of this MigrationObjectSummary.
        :type type: str

        :param object_status:
            The value to assign to the object_status property of this MigrationObjectSummary.
            Allowed values for this property are: "EXCLUDE", "INCLUDE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type object_status: str

        """
        self.swagger_types = {
            'owner': 'str',
            'object_name': 'str',
            'type': 'str',
            'object_status': 'str'
        }

        self.attribute_map = {
            'owner': 'owner',
            'object_name': 'objectName',
            'type': 'type',
            'object_status': 'objectStatus'
        }

        self._owner = None
        self._object_name = None
        self._type = None
        self._object_status = None

    @property
    def owner(self):
        """
        **[Required]** Gets the owner of this MigrationObjectSummary.
        Owner of the object (regular expression is allowed)


        :return: The owner of this MigrationObjectSummary.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this MigrationObjectSummary.
        Owner of the object (regular expression is allowed)


        :param owner: The owner of this MigrationObjectSummary.
        :type: str
        """
        self._owner = owner

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this MigrationObjectSummary.
        Name of the object (regular expression is allowed)


        :return: The object_name of this MigrationObjectSummary.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this MigrationObjectSummary.
        Name of the object (regular expression is allowed)


        :param object_name: The object_name of this MigrationObjectSummary.
        :type: str
        """
        self._object_name = object_name

    @property
    def type(self):
        """
        Gets the type of this MigrationObjectSummary.
        Type of object to exclude.
        If not specified, matching owners and object names of type TABLE would be excluded.


        :return: The type of this MigrationObjectSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this MigrationObjectSummary.
        Type of object to exclude.
        If not specified, matching owners and object names of type TABLE would be excluded.


        :param type: The type of this MigrationObjectSummary.
        :type: str
        """
        self._type = type

    @property
    def object_status(self):
        """
        Gets the object_status of this MigrationObjectSummary.
        Object status.

        Allowed values for this property are: "EXCLUDE", "INCLUDE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The object_status of this MigrationObjectSummary.
        :rtype: str
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this MigrationObjectSummary.
        Object status.


        :param object_status: The object_status of this MigrationObjectSummary.
        :type: str
        """
        allowed_values = ["EXCLUDE", "INCLUDE"]
        if not value_allowed_none_or_none_sentinel(object_status, allowed_values):
            object_status = 'UNKNOWN_ENUM_VALUE'
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
